import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:path/path.dart' as p;

/// App Ionicons icons (1972 icons)
///
/// - build svg for ionicons icon libraries
/// - constants link to svg icon resources
class Ionicons extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  const Ionicons(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  static Widget svgAsset(String assetName,
      {Key? key,
      bool matchTextDirection = false,
      AssetBundle? bundle,
      String? package,
      double? width,
      double? height,
      BoxFit fit = BoxFit.contain,
      AlignmentGeometry alignment = Alignment.center,
      bool allowDrawingOutsideViewBox = false,
      WidgetBuilder? placeholderBuilder,
      Color? color,
      BlendMode colorBlendMode = BlendMode.srcIn,
      String? semanticsLabel,
      bool excludeFromSemantics = false,
      Clip clipBehavior = Clip.hardEdge,
      bool cacheColorFilter = false,
      SvgTheme? theme}) {
    final path = p.join(
      // external library
      'packages/iconforest_ionicons/assets/images/ionicons/',
      // local library
      // 'assets/images/ionicons/',
      assetName,
    );
    return SvgPicture.asset(
      path,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  @override
  Widget build(BuildContext context) {
    return svgAsset(
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  static const String accessibility_outline = 'accessibility_outline.svg';
  static const String accessibility_sharp = 'accessibility_sharp.svg';
  static const String accessibility = 'accessibility.svg';
  static const String add_circle_outline = 'add_circle_outline.svg';
  static const String add_circle_sharp = 'add_circle_sharp.svg';
  static const String add_circle = 'add_circle.svg';
  static const String add_outline = 'add_outline.svg';
  static const String add_sharp = 'add_sharp.svg';
  static const String add = 'add.svg';
  static const String airplane_outline = 'airplane_outline.svg';
  static const String airplane_sharp = 'airplane_sharp.svg';
  static const String airplane = 'airplane.svg';
  static const String alarm_outline = 'alarm_outline.svg';
  static const String alarm_sharp = 'alarm_sharp.svg';
  static const String alarm = 'alarm.svg';
  static const String albums_outline = 'albums_outline.svg';
  static const String albums_sharp = 'albums_sharp.svg';
  static const String albums = 'albums.svg';
  static const String alert_circle_outline = 'alert_circle_outline.svg';
  static const String alert_circle_sharp = 'alert_circle_sharp.svg';
  static const String alert_circle = 'alert_circle.svg';
  static const String alert_outline = 'alert_outline.svg';
  static const String alert_sharp = 'alert_sharp.svg';
  static const String alert = 'alert.svg';
  static const String american_football_outline = 'american_football_outline.svg';
  static const String american_football_sharp = 'american_football_sharp.svg';
  static const String american_football = 'american_football.svg';
  static const String analytics_outline = 'analytics_outline.svg';
  static const String analytics_sharp = 'analytics_sharp.svg';
  static const String analytics = 'analytics.svg';
  static const String aperture_outline = 'aperture_outline.svg';
  static const String aperture_sharp = 'aperture_sharp.svg';
  static const String aperture = 'aperture.svg';
  static const String apps_outline = 'apps_outline.svg';
  static const String apps_sharp = 'apps_sharp.svg';
  static const String apps = 'apps.svg';
  static const String archive_outline = 'archive_outline.svg';
  static const String archive_sharp = 'archive_sharp.svg';
  static const String archive = 'archive.svg';
  static const String arrow_back_circle_outline = 'arrow_back_circle_outline.svg';
  static const String arrow_back_circle_sharp = 'arrow_back_circle_sharp.svg';
  static const String arrow_back_circle = 'arrow_back_circle.svg';
  static const String arrow_back_outline = 'arrow_back_outline.svg';
  static const String arrow_back_sharp = 'arrow_back_sharp.svg';
  static const String arrow_back = 'arrow_back.svg';
  static const String arrow_down_circle_outline = 'arrow_down_circle_outline.svg';
  static const String arrow_down_circle_sharp = 'arrow_down_circle_sharp.svg';
  static const String arrow_down_circle = 'arrow_down_circle.svg';
  static const String arrow_down_outline = 'arrow_down_outline.svg';
  static const String arrow_down_sharp = 'arrow_down_sharp.svg';
  static const String arrow_down = 'arrow_down.svg';
  static const String arrow_forward_circle_outline = 'arrow_forward_circle_outline.svg';
  static const String arrow_forward_circle_sharp = 'arrow_forward_circle_sharp.svg';
  static const String arrow_forward_circle = 'arrow_forward_circle.svg';
  static const String arrow_forward_outline = 'arrow_forward_outline.svg';
  static const String arrow_forward_sharp = 'arrow_forward_sharp.svg';
  static const String arrow_forward = 'arrow_forward.svg';
  static const String arrow_redo_circle_outline = 'arrow_redo_circle_outline.svg';
  static const String arrow_redo_circle_sharp = 'arrow_redo_circle_sharp.svg';
  static const String arrow_redo_circle = 'arrow_redo_circle.svg';
  static const String arrow_redo_outline = 'arrow_redo_outline.svg';
  static const String arrow_redo_sharp = 'arrow_redo_sharp.svg';
  static const String arrow_redo = 'arrow_redo.svg';
  static const String arrow_undo_circle_outline = 'arrow_undo_circle_outline.svg';
  static const String arrow_undo_circle_sharp = 'arrow_undo_circle_sharp.svg';
  static const String arrow_undo_circle = 'arrow_undo_circle.svg';
  static const String arrow_undo_outline = 'arrow_undo_outline.svg';
  static const String arrow_undo_sharp = 'arrow_undo_sharp.svg';
  static const String arrow_undo = 'arrow_undo.svg';
  static const String arrow_up_circle_outline = 'arrow_up_circle_outline.svg';
  static const String arrow_up_circle_sharp = 'arrow_up_circle_sharp.svg';
  static const String arrow_up_circle = 'arrow_up_circle.svg';
  static const String arrow_up_outline = 'arrow_up_outline.svg';
  static const String arrow_up_sharp = 'arrow_up_sharp.svg';
  static const String arrow_up = 'arrow_up.svg';
  static const String at_circle_outline = 'at_circle_outline.svg';
  static const String at_circle_sharp = 'at_circle_sharp.svg';
  static const String at_circle = 'at_circle.svg';
  static const String at_outline = 'at_outline.svg';
  static const String at_sharp = 'at_sharp.svg';
  static const String at = 'at.svg';
  static const String attach_outline = 'attach_outline.svg';
  static const String attach_sharp = 'attach_sharp.svg';
  static const String attach = 'attach.svg';
  static const String backspace_outline = 'backspace_outline.svg';
  static const String backspace_sharp = 'backspace_sharp.svg';
  static const String backspace = 'backspace.svg';
  static const String bag_add_outline = 'bag_add_outline.svg';
  static const String bag_add_sharp = 'bag_add_sharp.svg';
  static const String bag_add = 'bag_add.svg';
  static const String bag_check_outline = 'bag_check_outline.svg';
  static const String bag_check_sharp = 'bag_check_sharp.svg';
  static const String bag_check = 'bag_check.svg';
  static const String bag_handle_outline = 'bag_handle_outline.svg';
  static const String bag_handle_sharp = 'bag_handle_sharp.svg';
  static const String bag_handle = 'bag_handle.svg';
  static const String bag_outline = 'bag_outline.svg';
  static const String bag_remove_outline = 'bag_remove_outline.svg';
  static const String bag_remove_sharp = 'bag_remove_sharp.svg';
  static const String bag_remove = 'bag_remove.svg';
  static const String bag_sharp = 'bag_sharp.svg';
  static const String bag = 'bag.svg';
  static const String balloon_outline = 'balloon_outline.svg';
  static const String balloon_sharp = 'balloon_sharp.svg';
  static const String balloon = 'balloon.svg';
  static const String ban_outline = 'ban_outline.svg';
  static const String ban_sharp = 'ban_sharp.svg';
  static const String ban = 'ban.svg';
  static const String bandage_outline = 'bandage_outline.svg';
  static const String bandage_sharp = 'bandage_sharp.svg';
  static const String bandage = 'bandage.svg';
  static const String bar_chart_outline = 'bar_chart_outline.svg';
  static const String bar_chart_sharp = 'bar_chart_sharp.svg';
  static const String bar_chart = 'bar_chart.svg';
  static const String barbell_outline = 'barbell_outline.svg';
  static const String barbell_sharp = 'barbell_sharp.svg';
  static const String barbell = 'barbell.svg';
  static const String barcode_outline = 'barcode_outline.svg';
  static const String barcode_sharp = 'barcode_sharp.svg';
  static const String barcode = 'barcode.svg';
  static const String baseball_outline = 'baseball_outline.svg';
  static const String baseball_sharp = 'baseball_sharp.svg';
  static const String baseball = 'baseball.svg';
  static const String basket_outline = 'basket_outline.svg';
  static const String basket_sharp = 'basket_sharp.svg';
  static const String basket = 'basket.svg';
  static const String basketball_outline = 'basketball_outline.svg';
  static const String basketball_sharp = 'basketball_sharp.svg';
  static const String basketball = 'basketball.svg';
  static const String battery_charging_outline = 'battery_charging_outline.svg';
  static const String battery_charging_sharp = 'battery_charging_sharp.svg';
  static const String battery_charging = 'battery_charging.svg';
  static const String battery_dead_outline = 'battery_dead_outline.svg';
  static const String battery_dead_sharp = 'battery_dead_sharp.svg';
  static const String battery_dead = 'battery_dead.svg';
  static const String battery_full_outline = 'battery_full_outline.svg';
  static const String battery_full_sharp = 'battery_full_sharp.svg';
  static const String battery_full = 'battery_full.svg';
  static const String battery_half_outline = 'battery_half_outline.svg';
  static const String battery_half_sharp = 'battery_half_sharp.svg';
  static const String battery_half = 'battery_half.svg';
  static const String beaker_outline = 'beaker_outline.svg';
  static const String beaker_sharp = 'beaker_sharp.svg';
  static const String beaker = 'beaker.svg';
  static const String bed_outline = 'bed_outline.svg';
  static const String bed_sharp = 'bed_sharp.svg';
  static const String bed = 'bed.svg';
  static const String beer_outline = 'beer_outline.svg';
  static const String beer_sharp = 'beer_sharp.svg';
  static const String beer = 'beer.svg';
  static const String bicycle_outline = 'bicycle_outline.svg';
  static const String bicycle_sharp = 'bicycle_sharp.svg';
  static const String bicycle = 'bicycle.svg';
  static const String bluetooth_outline = 'bluetooth_outline.svg';
  static const String bluetooth_sharp = 'bluetooth_sharp.svg';
  static const String bluetooth = 'bluetooth.svg';
  static const String boat_outline = 'boat_outline.svg';
  static const String boat_sharp = 'boat_sharp.svg';
  static const String boat = 'boat.svg';
  static const String body_outline = 'body_outline.svg';
  static const String body_sharp = 'body_sharp.svg';
  static const String body = 'body.svg';
  static const String bonfire_outline = 'bonfire_outline.svg';
  static const String bonfire_sharp = 'bonfire_sharp.svg';
  static const String bonfire = 'bonfire.svg';
  static const String book_outline = 'book_outline.svg';
  static const String book_sharp = 'book_sharp.svg';
  static const String book = 'book.svg';
  static const String bookmark_outline = 'bookmark_outline.svg';
  static const String bookmark_sharp = 'bookmark_sharp.svg';
  static const String bookmark = 'bookmark.svg';
  static const String bookmarks_outline = 'bookmarks_outline.svg';
  static const String bookmarks_sharp = 'bookmarks_sharp.svg';
  static const String bookmarks = 'bookmarks.svg';
  static const String bowling_ball_outline = 'bowling_ball_outline.svg';
  static const String bowling_ball_sharp = 'bowling_ball_sharp.svg';
  static const String bowling_ball = 'bowling_ball.svg';
  static const String briefcase_outline = 'briefcase_outline.svg';
  static const String briefcase_sharp = 'briefcase_sharp.svg';
  static const String briefcase = 'briefcase.svg';
  static const String browsers_outline = 'browsers_outline.svg';
  static const String browsers_sharp = 'browsers_sharp.svg';
  static const String browsers = 'browsers.svg';
  static const String brush_outline = 'brush_outline.svg';
  static const String brush_sharp = 'brush_sharp.svg';
  static const String brush = 'brush.svg';
  static const String bug_outline = 'bug_outline.svg';
  static const String bug_sharp = 'bug_sharp.svg';
  static const String bug = 'bug.svg';
  static const String build_outline = 'build_outline.svg';
  static const String build_sharp = 'build_sharp.svg';
  static const String build_ = 'build.svg';
  static const String bulb_outline = 'bulb_outline.svg';
  static const String bulb_sharp = 'bulb_sharp.svg';
  static const String bulb = 'bulb.svg';
  static const String bus_outline = 'bus_outline.svg';
  static const String bus_sharp = 'bus_sharp.svg';
  static const String bus = 'bus.svg';
  static const String business_outline = 'business_outline.svg';
  static const String business_sharp = 'business_sharp.svg';
  static const String business = 'business.svg';
  static const String cafe_outline = 'cafe_outline.svg';
  static const String cafe_sharp = 'cafe_sharp.svg';
  static const String cafe = 'cafe.svg';
  static const String calculator_outline = 'calculator_outline.svg';
  static const String calculator_sharp = 'calculator_sharp.svg';
  static const String calculator = 'calculator.svg';
  static const String calendar_clear_outline = 'calendar_clear_outline.svg';
  static const String calendar_clear_sharp = 'calendar_clear_sharp.svg';
  static const String calendar_clear = 'calendar_clear.svg';
  static const String calendar_number_outline = 'calendar_number_outline.svg';
  static const String calendar_number_sharp = 'calendar_number_sharp.svg';
  static const String calendar_number = 'calendar_number.svg';
  static const String calendar_outline = 'calendar_outline.svg';
  static const String calendar_sharp = 'calendar_sharp.svg';
  static const String calendar = 'calendar.svg';
  static const String call_outline = 'call_outline.svg';
  static const String call_sharp = 'call_sharp.svg';
  static const String call = 'call.svg';
  static const String camera_outline = 'camera_outline.svg';
  static const String camera_reverse_outline = 'camera_reverse_outline.svg';
  static const String camera_reverse_sharp = 'camera_reverse_sharp.svg';
  static const String camera_reverse = 'camera_reverse.svg';
  static const String camera_sharp = 'camera_sharp.svg';
  static const String camera = 'camera.svg';
  static const String car_outline = 'car_outline.svg';
  static const String car_sharp = 'car_sharp.svg';
  static const String car_sport_outline = 'car_sport_outline.svg';
  static const String car_sport_sharp = 'car_sport_sharp.svg';
  static const String car_sport = 'car_sport.svg';
  static const String car = 'car.svg';
  static const String card_outline = 'card_outline.svg';
  static const String card_sharp = 'card_sharp.svg';
  static const String card = 'card.svg';
  static const String caret_back_circle_outline = 'caret_back_circle_outline.svg';
  static const String caret_back_circle_sharp = 'caret_back_circle_sharp.svg';
  static const String caret_back_circle = 'caret_back_circle.svg';
  static const String caret_back_outline = 'caret_back_outline.svg';
  static const String caret_back_sharp = 'caret_back_sharp.svg';
  static const String caret_back = 'caret_back.svg';
  static const String caret_down_circle_outline = 'caret_down_circle_outline.svg';
  static const String caret_down_circle_sharp = 'caret_down_circle_sharp.svg';
  static const String caret_down_circle = 'caret_down_circle.svg';
  static const String caret_down_outline = 'caret_down_outline.svg';
  static const String caret_down_sharp = 'caret_down_sharp.svg';
  static const String caret_down = 'caret_down.svg';
  static const String caret_forward_circle_outline = 'caret_forward_circle_outline.svg';
  static const String caret_forward_circle_sharp = 'caret_forward_circle_sharp.svg';
  static const String caret_forward_circle = 'caret_forward_circle.svg';
  static const String caret_forward_outline = 'caret_forward_outline.svg';
  static const String caret_forward_sharp = 'caret_forward_sharp.svg';
  static const String caret_forward = 'caret_forward.svg';
  static const String caret_up_circle_outline = 'caret_up_circle_outline.svg';
  static const String caret_up_circle_sharp = 'caret_up_circle_sharp.svg';
  static const String caret_up_circle = 'caret_up_circle.svg';
  static const String caret_up_outline = 'caret_up_outline.svg';
  static const String caret_up_sharp = 'caret_up_sharp.svg';
  static const String caret_up = 'caret_up.svg';
  static const String cart_outline = 'cart_outline.svg';
  static const String cart_sharp = 'cart_sharp.svg';
  static const String cart = 'cart.svg';
  static const String cash_outline = 'cash_outline.svg';
  static const String cash_sharp = 'cash_sharp.svg';
  static const String cash = 'cash.svg';
  static const String cellular_outline = 'cellular_outline.svg';
  static const String cellular_sharp = 'cellular_sharp.svg';
  static const String cellular = 'cellular.svg';
  static const String chatbox_ellipses_outline = 'chatbox_ellipses_outline.svg';
  static const String chatbox_ellipses_sharp = 'chatbox_ellipses_sharp.svg';
  static const String chatbox_ellipses = 'chatbox_ellipses.svg';
  static const String chatbox_outline = 'chatbox_outline.svg';
  static const String chatbox_sharp = 'chatbox_sharp.svg';
  static const String chatbox = 'chatbox.svg';
  static const String chatbubble_ellipses_outline = 'chatbubble_ellipses_outline.svg';
  static const String chatbubble_ellipses_sharp = 'chatbubble_ellipses_sharp.svg';
  static const String chatbubble_ellipses = 'chatbubble_ellipses.svg';
  static const String chatbubble_outline = 'chatbubble_outline.svg';
  static const String chatbubble_sharp = 'chatbubble_sharp.svg';
  static const String chatbubble = 'chatbubble.svg';
  static const String chatbubbles_outline = 'chatbubbles_outline.svg';
  static const String chatbubbles_sharp = 'chatbubbles_sharp.svg';
  static const String chatbubbles = 'chatbubbles.svg';
  static const String checkbox_outline = 'checkbox_outline.svg';
  static const String checkbox_sharp = 'checkbox_sharp.svg';
  static const String checkbox = 'checkbox.svg';
  static const String checkmark_circle_outline = 'checkmark_circle_outline.svg';
  static const String checkmark_circle_sharp = 'checkmark_circle_sharp.svg';
  static const String checkmark_circle = 'checkmark_circle.svg';
  static const String checkmark_done_circle_outline = 'checkmark_done_circle_outline.svg';
  static const String checkmark_done_circle_sharp = 'checkmark_done_circle_sharp.svg';
  static const String checkmark_done_circle = 'checkmark_done_circle.svg';
  static const String checkmark_done_outline = 'checkmark_done_outline.svg';
  static const String checkmark_done_sharp = 'checkmark_done_sharp.svg';
  static const String checkmark_done = 'checkmark_done.svg';
  static const String checkmark_outline = 'checkmark_outline.svg';
  static const String checkmark_sharp = 'checkmark_sharp.svg';
  static const String checkmark = 'checkmark.svg';
  static const String chevron_back_circle_outline = 'chevron_back_circle_outline.svg';
  static const String chevron_back_circle_sharp = 'chevron_back_circle_sharp.svg';
  static const String chevron_back_circle = 'chevron_back_circle.svg';
  static const String chevron_back_outline = 'chevron_back_outline.svg';
  static const String chevron_back_sharp = 'chevron_back_sharp.svg';
  static const String chevron_back = 'chevron_back.svg';
  static const String chevron_down_circle_outline = 'chevron_down_circle_outline.svg';
  static const String chevron_down_circle_sharp = 'chevron_down_circle_sharp.svg';
  static const String chevron_down_circle = 'chevron_down_circle.svg';
  static const String chevron_down_outline = 'chevron_down_outline.svg';
  static const String chevron_down_sharp = 'chevron_down_sharp.svg';
  static const String chevron_down = 'chevron_down.svg';
  static const String chevron_forward_circle_outline = 'chevron_forward_circle_outline.svg';
  static const String chevron_forward_circle_sharp = 'chevron_forward_circle_sharp.svg';
  static const String chevron_forward_circle = 'chevron_forward_circle.svg';
  static const String chevron_forward_outline = 'chevron_forward_outline.svg';
  static const String chevron_forward_sharp = 'chevron_forward_sharp.svg';
  static const String chevron_forward = 'chevron_forward.svg';
  static const String chevron_up_circle_outline = 'chevron_up_circle_outline.svg';
  static const String chevron_up_circle_sharp = 'chevron_up_circle_sharp.svg';
  static const String chevron_up_circle = 'chevron_up_circle.svg';
  static const String chevron_up_outline = 'chevron_up_outline.svg';
  static const String chevron_up_sharp = 'chevron_up_sharp.svg';
  static const String chevron_up = 'chevron_up.svg';
  static const String clipboard_outline = 'clipboard_outline.svg';
  static const String clipboard_sharp = 'clipboard_sharp.svg';
  static const String clipboard = 'clipboard.svg';
  static const String close_circle_outline = 'close_circle_outline.svg';
  static const String close_circle_sharp = 'close_circle_sharp.svg';
  static const String close_circle = 'close_circle.svg';
  static const String close_outline = 'close_outline.svg';
  static const String close_sharp = 'close_sharp.svg';
  static const String close = 'close.svg';
  static const String cloud_circle_outline = 'cloud_circle_outline.svg';
  static const String cloud_circle_sharp = 'cloud_circle_sharp.svg';
  static const String cloud_circle = 'cloud_circle.svg';
  static const String cloud_done_outline = 'cloud_done_outline.svg';
  static const String cloud_done_sharp = 'cloud_done_sharp.svg';
  static const String cloud_done = 'cloud_done.svg';
  static const String cloud_download_outline = 'cloud_download_outline.svg';
  static const String cloud_download_sharp = 'cloud_download_sharp.svg';
  static const String cloud_download = 'cloud_download.svg';
  static const String cloud_offline_outline = 'cloud_offline_outline.svg';
  static const String cloud_offline_sharp = 'cloud_offline_sharp.svg';
  static const String cloud_offline = 'cloud_offline.svg';
  static const String cloud_outline = 'cloud_outline.svg';
  static const String cloud_sharp = 'cloud_sharp.svg';
  static const String cloud_upload_outline = 'cloud_upload_outline.svg';
  static const String cloud_upload_sharp = 'cloud_upload_sharp.svg';
  static const String cloud_upload = 'cloud_upload.svg';
  static const String cloud = 'cloud.svg';
  static const String cloudy_night_outline = 'cloudy_night_outline.svg';
  static const String cloudy_night_sharp = 'cloudy_night_sharp.svg';
  static const String cloudy_night = 'cloudy_night.svg';
  static const String cloudy_outline = 'cloudy_outline.svg';
  static const String cloudy_sharp = 'cloudy_sharp.svg';
  static const String cloudy = 'cloudy.svg';
  static const String code_download_outline = 'code_download_outline.svg';
  static const String code_download_sharp = 'code_download_sharp.svg';
  static const String code_download = 'code_download.svg';
  static const String code_outline = 'code_outline.svg';
  static const String code_sharp = 'code_sharp.svg';
  static const String code_slash_outline = 'code_slash_outline.svg';
  static const String code_slash_sharp = 'code_slash_sharp.svg';
  static const String code_slash = 'code_slash.svg';
  static const String code_working_outline = 'code_working_outline.svg';
  static const String code_working_sharp = 'code_working_sharp.svg';
  static const String code_working = 'code_working.svg';
  static const String code = 'code.svg';
  static const String cog_outline = 'cog_outline.svg';
  static const String cog_sharp = 'cog_sharp.svg';
  static const String cog = 'cog.svg';
  static const String color_fill_outline = 'color_fill_outline.svg';
  static const String color_fill_sharp = 'color_fill_sharp.svg';
  static const String color_fill = 'color_fill.svg';
  static const String color_filter_outline = 'color_filter_outline.svg';
  static const String color_filter_sharp = 'color_filter_sharp.svg';
  static const String color_filter = 'color_filter.svg';
  static const String color_palette_outline = 'color_palette_outline.svg';
  static const String color_palette_sharp = 'color_palette_sharp.svg';
  static const String color_palette = 'color_palette.svg';
  static const String color_wand_outline = 'color_wand_outline.svg';
  static const String color_wand_sharp = 'color_wand_sharp.svg';
  static const String color_wand = 'color_wand.svg';
  static const String compass_outline = 'compass_outline.svg';
  static const String compass_sharp = 'compass_sharp.svg';
  static const String compass = 'compass.svg';
  static const String construct_outline = 'construct_outline.svg';
  static const String construct_sharp = 'construct_sharp.svg';
  static const String construct = 'construct.svg';
  static const String contract_outline = 'contract_outline.svg';
  static const String contract_sharp = 'contract_sharp.svg';
  static const String contract = 'contract.svg';
  static const String contrast_outline = 'contrast_outline.svg';
  static const String contrast_sharp = 'contrast_sharp.svg';
  static const String contrast = 'contrast.svg';
  static const String copy_outline = 'copy_outline.svg';
  static const String copy_sharp = 'copy_sharp.svg';
  static const String copy = 'copy.svg';
  static const String create_outline = 'create_outline.svg';
  static const String create_sharp = 'create_sharp.svg';
  static const String create = 'create.svg';
  static const String crop_outline = 'crop_outline.svg';
  static const String crop_sharp = 'crop_sharp.svg';
  static const String crop = 'crop.svg';
  static const String cube_outline = 'cube_outline.svg';
  static const String cube_sharp = 'cube_sharp.svg';
  static const String cube = 'cube.svg';
  static const String cut_outline = 'cut_outline.svg';
  static const String cut_sharp = 'cut_sharp.svg';
  static const String cut = 'cut.svg';
  static const String desktop_outline = 'desktop_outline.svg';
  static const String desktop_sharp = 'desktop_sharp.svg';
  static const String desktop = 'desktop.svg';
  static const String diamond_outline = 'diamond_outline.svg';
  static const String diamond_sharp = 'diamond_sharp.svg';
  static const String diamond = 'diamond.svg';
  static const String dice_outline = 'dice_outline.svg';
  static const String dice_sharp = 'dice_sharp.svg';
  static const String dice = 'dice.svg';
  static const String disc_outline = 'disc_outline.svg';
  static const String disc_sharp = 'disc_sharp.svg';
  static const String disc = 'disc.svg';
  static const String document_attach_outline = 'document_attach_outline.svg';
  static const String document_attach_sharp = 'document_attach_sharp.svg';
  static const String document_attach = 'document_attach.svg';
  static const String document_lock_outline = 'document_lock_outline.svg';
  static const String document_lock_sharp = 'document_lock_sharp.svg';
  static const String document_lock = 'document_lock.svg';
  static const String document_outline = 'document_outline.svg';
  static const String document_sharp = 'document_sharp.svg';
  static const String document_text_outline = 'document_text_outline.svg';
  static const String document_text_sharp = 'document_text_sharp.svg';
  static const String document_text = 'document_text.svg';
  static const String document = 'document.svg';
  static const String documents_outline = 'documents_outline.svg';
  static const String documents_sharp = 'documents_sharp.svg';
  static const String documents = 'documents.svg';
  static const String download_outline = 'download_outline.svg';
  static const String download_sharp = 'download_sharp.svg';
  static const String download = 'download.svg';
  static const String duplicate_outline = 'duplicate_outline.svg';
  static const String duplicate_sharp = 'duplicate_sharp.svg';
  static const String duplicate = 'duplicate.svg';
  static const String ear_outline = 'ear_outline.svg';
  static const String ear_sharp = 'ear_sharp.svg';
  static const String ear = 'ear.svg';
  static const String earth_outline = 'earth_outline.svg';
  static const String earth_sharp = 'earth_sharp.svg';
  static const String earth = 'earth.svg';
  static const String easel_outline = 'easel_outline.svg';
  static const String easel_sharp = 'easel_sharp.svg';
  static const String easel = 'easel.svg';
  static const String egg_outline = 'egg_outline.svg';
  static const String egg_sharp = 'egg_sharp.svg';
  static const String egg = 'egg.svg';
  static const String ellipse_outline = 'ellipse_outline.svg';
  static const String ellipse_sharp = 'ellipse_sharp.svg';
  static const String ellipse = 'ellipse.svg';
  static const String ellipsis_horizontal_circle_outline = 'ellipsis_horizontal_circle_outline.svg';
  static const String ellipsis_horizontal_circle_sharp = 'ellipsis_horizontal_circle_sharp.svg';
  static const String ellipsis_horizontal_circle = 'ellipsis_horizontal_circle.svg';
  static const String ellipsis_horizontal_outline = 'ellipsis_horizontal_outline.svg';
  static const String ellipsis_horizontal_sharp = 'ellipsis_horizontal_sharp.svg';
  static const String ellipsis_horizontal = 'ellipsis_horizontal.svg';
  static const String ellipsis_vertical_circle_outline = 'ellipsis_vertical_circle_outline.svg';
  static const String ellipsis_vertical_circle_sharp = 'ellipsis_vertical_circle_sharp.svg';
  static const String ellipsis_vertical_circle = 'ellipsis_vertical_circle.svg';
  static const String ellipsis_vertical_outline = 'ellipsis_vertical_outline.svg';
  static const String ellipsis_vertical_sharp = 'ellipsis_vertical_sharp.svg';
  static const String ellipsis_vertical = 'ellipsis_vertical.svg';
  static const String enter_outline = 'enter_outline.svg';
  static const String enter_sharp = 'enter_sharp.svg';
  static const String enter = 'enter.svg';
  static const String exit_outline = 'exit_outline.svg';
  static const String exit_sharp = 'exit_sharp.svg';
  static const String exit = 'exit.svg';
  static const String expand_outline = 'expand_outline.svg';
  static const String expand_sharp = 'expand_sharp.svg';
  static const String expand = 'expand.svg';
  static const String extension_puzzle_outline = 'extension_puzzle_outline.svg';
  static const String extension_puzzle_sharp = 'extension_puzzle_sharp.svg';
  static const String extension_puzzle = 'extension_puzzle.svg';
  static const String eye_off_outline = 'eye_off_outline.svg';
  static const String eye_off_sharp = 'eye_off_sharp.svg';
  static const String eye_off = 'eye_off.svg';
  static const String eye_outline = 'eye_outline.svg';
  static const String eye_sharp = 'eye_sharp.svg';
  static const String eye = 'eye.svg';
  static const String eyedrop_outline = 'eyedrop_outline.svg';
  static const String eyedrop_sharp = 'eyedrop_sharp.svg';
  static const String eyedrop = 'eyedrop.svg';
  static const String fast_food_outline = 'fast_food_outline.svg';
  static const String fast_food_sharp = 'fast_food_sharp.svg';
  static const String fast_food = 'fast_food.svg';
  static const String female_outline = 'female_outline.svg';
  static const String female_sharp = 'female_sharp.svg';
  static const String female = 'female.svg';
  static const String file_tray_full_outline = 'file_tray_full_outline.svg';
  static const String file_tray_full_sharp = 'file_tray_full_sharp.svg';
  static const String file_tray_full = 'file_tray_full.svg';
  static const String file_tray_outline = 'file_tray_outline.svg';
  static const String file_tray_sharp = 'file_tray_sharp.svg';
  static const String file_tray_stacked_outline = 'file_tray_stacked_outline.svg';
  static const String file_tray_stacked_sharp = 'file_tray_stacked_sharp.svg';
  static const String file_tray_stacked = 'file_tray_stacked.svg';
  static const String file_tray = 'file_tray.svg';
  static const String film_outline = 'film_outline.svg';
  static const String film_sharp = 'film_sharp.svg';
  static const String film = 'film.svg';
  static const String filter_circle_outline = 'filter_circle_outline.svg';
  static const String filter_circle_sharp = 'filter_circle_sharp.svg';
  static const String filter_circle = 'filter_circle.svg';
  static const String filter_outline = 'filter_outline.svg';
  static const String filter_sharp = 'filter_sharp.svg';
  static const String filter = 'filter.svg';
  static const String finger_print_outline = 'finger_print_outline.svg';
  static const String finger_print_sharp = 'finger_print_sharp.svg';
  static const String finger_print = 'finger_print.svg';
  static const String fish_outline = 'fish_outline.svg';
  static const String fish_sharp = 'fish_sharp.svg';
  static const String fish = 'fish.svg';
  static const String fitness_outline = 'fitness_outline.svg';
  static const String fitness_sharp = 'fitness_sharp.svg';
  static const String fitness = 'fitness.svg';
  static const String flag_outline = 'flag_outline.svg';
  static const String flag_sharp = 'flag_sharp.svg';
  static const String flag = 'flag.svg';
  static const String flame_outline = 'flame_outline.svg';
  static const String flame_sharp = 'flame_sharp.svg';
  static const String flame = 'flame.svg';
  static const String flash_off_outline = 'flash_off_outline.svg';
  static const String flash_off_sharp = 'flash_off_sharp.svg';
  static const String flash_off = 'flash_off.svg';
  static const String flash_outline = 'flash_outline.svg';
  static const String flash_sharp = 'flash_sharp.svg';
  static const String flash = 'flash.svg';
  static const String flashlight_outline = 'flashlight_outline.svg';
  static const String flashlight_sharp = 'flashlight_sharp.svg';
  static const String flashlight = 'flashlight.svg';
  static const String flask_outline = 'flask_outline.svg';
  static const String flask_sharp = 'flask_sharp.svg';
  static const String flask = 'flask.svg';
  static const String flower_outline = 'flower_outline.svg';
  static const String flower_sharp = 'flower_sharp.svg';
  static const String flower = 'flower.svg';
  static const String folder_open_outline = 'folder_open_outline.svg';
  static const String folder_open_sharp = 'folder_open_sharp.svg';
  static const String folder_open = 'folder_open.svg';
  static const String folder_outline = 'folder_outline.svg';
  static const String folder_sharp = 'folder_sharp.svg';
  static const String folder = 'folder.svg';
  static const String football_outline = 'football_outline.svg';
  static const String football_sharp = 'football_sharp.svg';
  static const String football = 'football.svg';
  static const String footsteps_outline = 'footsteps_outline.svg';
  static const String footsteps_sharp = 'footsteps_sharp.svg';
  static const String footsteps = 'footsteps.svg';
  static const String funnel_outline = 'funnel_outline.svg';
  static const String funnel_sharp = 'funnel_sharp.svg';
  static const String funnel = 'funnel.svg';
  static const String game_controller_outline = 'game_controller_outline.svg';
  static const String game_controller_sharp = 'game_controller_sharp.svg';
  static const String game_controller = 'game_controller.svg';
  static const String gift_outline = 'gift_outline.svg';
  static const String gift_sharp = 'gift_sharp.svg';
  static const String gift = 'gift.svg';
  static const String git_branch_outline = 'git_branch_outline.svg';
  static const String git_branch_sharp = 'git_branch_sharp.svg';
  static const String git_branch = 'git_branch.svg';
  static const String git_commit_outline = 'git_commit_outline.svg';
  static const String git_commit_sharp = 'git_commit_sharp.svg';
  static const String git_commit = 'git_commit.svg';
  static const String git_compare_outline = 'git_compare_outline.svg';
  static const String git_compare_sharp = 'git_compare_sharp.svg';
  static const String git_compare = 'git_compare.svg';
  static const String git_merge_outline = 'git_merge_outline.svg';
  static const String git_merge_sharp = 'git_merge_sharp.svg';
  static const String git_merge = 'git_merge.svg';
  static const String git_network_outline = 'git_network_outline.svg';
  static const String git_network_sharp = 'git_network_sharp.svg';
  static const String git_network = 'git_network.svg';
  static const String git_pull_request_outline = 'git_pull_request_outline.svg';
  static const String git_pull_request_sharp = 'git_pull_request_sharp.svg';
  static const String git_pull_request = 'git_pull_request.svg';
  static const String glasses_outline = 'glasses_outline.svg';
  static const String glasses_sharp = 'glasses_sharp.svg';
  static const String glasses = 'glasses.svg';
  static const String globe_outline = 'globe_outline.svg';
  static const String globe_sharp = 'globe_sharp.svg';
  static const String globe = 'globe.svg';
  static const String golf_outline = 'golf_outline.svg';
  static const String golf_sharp = 'golf_sharp.svg';
  static const String golf = 'golf.svg';
  static const String grid_outline = 'grid_outline.svg';
  static const String grid_sharp = 'grid_sharp.svg';
  static const String grid = 'grid.svg';
  static const String hammer_outline = 'hammer_outline.svg';
  static const String hammer_sharp = 'hammer_sharp.svg';
  static const String hammer = 'hammer.svg';
  static const String hand_left_outline = 'hand_left_outline.svg';
  static const String hand_left_sharp = 'hand_left_sharp.svg';
  static const String hand_left = 'hand_left.svg';
  static const String hand_right_outline = 'hand_right_outline.svg';
  static const String hand_right_sharp = 'hand_right_sharp.svg';
  static const String hand_right = 'hand_right.svg';
  static const String happy_outline = 'happy_outline.svg';
  static const String happy_sharp = 'happy_sharp.svg';
  static const String happy = 'happy.svg';
  static const String hardware_chip_outline = 'hardware_chip_outline.svg';
  static const String hardware_chip_sharp = 'hardware_chip_sharp.svg';
  static const String hardware_chip = 'hardware_chip.svg';
  static const String headset_outline = 'headset_outline.svg';
  static const String headset_sharp = 'headset_sharp.svg';
  static const String headset = 'headset.svg';
  static const String heart_circle_outline = 'heart_circle_outline.svg';
  static const String heart_circle_sharp = 'heart_circle_sharp.svg';
  static const String heart_circle = 'heart_circle.svg';
  static const String heart_dislike_circle_outline = 'heart_dislike_circle_outline.svg';
  static const String heart_dislike_circle_sharp = 'heart_dislike_circle_sharp.svg';
  static const String heart_dislike_circle = 'heart_dislike_circle.svg';
  static const String heart_dislike_outline = 'heart_dislike_outline.svg';
  static const String heart_dislike_sharp = 'heart_dislike_sharp.svg';
  static const String heart_dislike = 'heart_dislike.svg';
  static const String heart_half_outline = 'heart_half_outline.svg';
  static const String heart_half_sharp = 'heart_half_sharp.svg';
  static const String heart_half = 'heart_half.svg';
  static const String heart_outline = 'heart_outline.svg';
  static const String heart_sharp = 'heart_sharp.svg';
  static const String heart = 'heart.svg';
  static const String help_buoy_outline = 'help_buoy_outline.svg';
  static const String help_buoy_sharp = 'help_buoy_sharp.svg';
  static const String help_buoy = 'help_buoy.svg';
  static const String help_circle_outline = 'help_circle_outline.svg';
  static const String help_circle_sharp = 'help_circle_sharp.svg';
  static const String help_circle = 'help_circle.svg';
  static const String help_outline = 'help_outline.svg';
  static const String help_sharp = 'help_sharp.svg';
  static const String help = 'help.svg';
  static const String home_outline = 'home_outline.svg';
  static const String home_sharp = 'home_sharp.svg';
  static const String home = 'home.svg';
  static const String hourglass_outline = 'hourglass_outline.svg';
  static const String hourglass_sharp = 'hourglass_sharp.svg';
  static const String hourglass = 'hourglass.svg';
  static const String ice_cream_outline = 'ice_cream_outline.svg';
  static const String ice_cream_sharp = 'ice_cream_sharp.svg';
  static const String ice_cream = 'ice_cream.svg';
  static const String id_card_outline = 'id_card_outline.svg';
  static const String id_card_sharp = 'id_card_sharp.svg';
  static const String id_card = 'id_card.svg';
  static const String image_outline = 'image_outline.svg';
  static const String image_sharp = 'image_sharp.svg';
  static const String image = 'image.svg';
  static const String images_outline = 'images_outline.svg';
  static const String images_sharp = 'images_sharp.svg';
  static const String images = 'images.svg';
  static const String infinite_outline = 'infinite_outline.svg';
  static const String infinite_sharp = 'infinite_sharp.svg';
  static const String infinite = 'infinite.svg';
  static const String information_circle_outline = 'information_circle_outline.svg';
  static const String information_circle_sharp = 'information_circle_sharp.svg';
  static const String information_circle = 'information_circle.svg';
  static const String information_outline = 'information_outline.svg';
  static const String information_sharp = 'information_sharp.svg';
  static const String information = 'information.svg';
  static const String invert_mode_outline = 'invert_mode_outline.svg';
  static const String invert_mode_sharp = 'invert_mode_sharp.svg';
  static const String invert_mode = 'invert_mode.svg';
  static const String ios_add_circle_outline = 'ios_add_circle_outline.svg';
  static const String ios_add_circle = 'ios_add_circle.svg';
  static const String ios_add = 'ios_add.svg';
  static const String ios_airplane = 'ios_airplane.svg';
  static const String ios_alarm = 'ios_alarm.svg';
  static const String ios_albums = 'ios_albums.svg';
  static const String ios_alert = 'ios_alert.svg';
  static const String ios_american_football = 'ios_american_football.svg';
  static const String ios_analytics = 'ios_analytics.svg';
  static const String ios_aperture = 'ios_aperture.svg';
  static const String ios_apps = 'ios_apps.svg';
  static const String ios_appstore = 'ios_appstore.svg';
  static const String ios_archive = 'ios_archive.svg';
  static const String ios_arrow_back = 'ios_arrow_back.svg';
  static const String ios_arrow_down = 'ios_arrow_down.svg';
  static const String ios_arrow_dropdown_circle = 'ios_arrow_dropdown_circle.svg';
  static const String ios_arrow_dropdown = 'ios_arrow_dropdown.svg';
  static const String ios_arrow_dropleft_circle = 'ios_arrow_dropleft_circle.svg';
  static const String ios_arrow_dropleft = 'ios_arrow_dropleft.svg';
  static const String ios_arrow_dropright_circle = 'ios_arrow_dropright_circle.svg';
  static const String ios_arrow_dropright = 'ios_arrow_dropright.svg';
  static const String ios_arrow_dropup_circle = 'ios_arrow_dropup_circle.svg';
  static const String ios_arrow_dropup = 'ios_arrow_dropup.svg';
  static const String ios_arrow_forward = 'ios_arrow_forward.svg';
  static const String ios_arrow_round_back = 'ios_arrow_round_back.svg';
  static const String ios_arrow_round_down = 'ios_arrow_round_down.svg';
  static const String ios_arrow_round_forward = 'ios_arrow_round_forward.svg';
  static const String ios_arrow_round_up = 'ios_arrow_round_up.svg';
  static const String ios_arrow_up = 'ios_arrow_up.svg';
  static const String ios_at = 'ios_at.svg';
  static const String ios_attach = 'ios_attach.svg';
  static const String ios_backspace = 'ios_backspace.svg';
  static const String ios_barcode = 'ios_barcode.svg';
  static const String ios_baseball = 'ios_baseball.svg';
  static const String ios_basket = 'ios_basket.svg';
  static const String ios_basketball = 'ios_basketball.svg';
  static const String ios_battery_charging = 'ios_battery_charging.svg';
  static const String ios_battery_dead = 'ios_battery_dead.svg';
  static const String ios_battery_full = 'ios_battery_full.svg';
  static const String ios_beaker = 'ios_beaker.svg';
  static const String ios_bed = 'ios_bed.svg';
  static const String ios_beer = 'ios_beer.svg';
  static const String ios_bicycle = 'ios_bicycle.svg';
  static const String ios_bluetooth = 'ios_bluetooth.svg';
  static const String ios_boat = 'ios_boat.svg';
  static const String ios_body = 'ios_body.svg';
  static const String ios_bonfire = 'ios_bonfire.svg';
  static const String ios_book = 'ios_book.svg';
  static const String ios_bookmark = 'ios_bookmark.svg';
  static const String ios_bookmarks = 'ios_bookmarks.svg';
  static const String ios_bowtie = 'ios_bowtie.svg';
  static const String ios_briefcase = 'ios_briefcase.svg';
  static const String ios_browsers = 'ios_browsers.svg';
  static const String ios_brush = 'ios_brush.svg';
  static const String ios_bug = 'ios_bug.svg';
  static const String ios_build = 'ios_build.svg';
  static const String ios_bulb = 'ios_bulb.svg';
  static const String ios_bus = 'ios_bus.svg';
  static const String ios_business = 'ios_business.svg';
  static const String ios_cafe = 'ios_cafe.svg';
  static const String ios_calculator = 'ios_calculator.svg';
  static const String ios_calendar = 'ios_calendar.svg';
  static const String ios_call = 'ios_call.svg';
  static const String ios_camera = 'ios_camera.svg';
  static const String ios_car = 'ios_car.svg';
  static const String ios_card = 'ios_card.svg';
  static const String ios_cart = 'ios_cart.svg';
  static const String ios_cash = 'ios_cash.svg';
  static const String ios_cellular = 'ios_cellular.svg';
  static const String ios_chatboxes = 'ios_chatboxes.svg';
  static const String ios_chatbubbles = 'ios_chatbubbles.svg';
  static const String ios_checkbox_outline = 'ios_checkbox_outline.svg';
  static const String ios_checkbox = 'ios_checkbox.svg';
  static const String ios_checkmark_circle_outline = 'ios_checkmark_circle_outline.svg';
  static const String ios_checkmark_circle = 'ios_checkmark_circle.svg';
  static const String ios_checkmark = 'ios_checkmark.svg';
  static const String ios_clipboard = 'ios_clipboard.svg';
  static const String ios_clock = 'ios_clock.svg';
  static const String ios_close_circle_outline = 'ios_close_circle_outline.svg';
  static const String ios_close_circle = 'ios_close_circle.svg';
  static const String ios_close = 'ios_close.svg';
  static const String ios_cloud_circle = 'ios_cloud_circle.svg';
  static const String ios_cloud_done = 'ios_cloud_done.svg';
  static const String ios_cloud_download = 'ios_cloud_download.svg';
  static const String ios_cloud_outline = 'ios_cloud_outline.svg';
  static const String ios_cloud_upload = 'ios_cloud_upload.svg';
  static const String ios_cloud = 'ios_cloud.svg';
  static const String ios_cloudy_night = 'ios_cloudy_night.svg';
  static const String ios_cloudy = 'ios_cloudy.svg';
  static const String ios_code_download = 'ios_code_download.svg';
  static const String ios_code_working = 'ios_code_working.svg';
  static const String ios_code = 'ios_code.svg';
  static const String ios_cog = 'ios_cog.svg';
  static const String ios_color_fill = 'ios_color_fill.svg';
  static const String ios_color_filter = 'ios_color_filter.svg';
  static const String ios_color_palette = 'ios_color_palette.svg';
  static const String ios_color_wand = 'ios_color_wand.svg';
  static const String ios_compass = 'ios_compass.svg';
  static const String ios_construct = 'ios_construct.svg';
  static const String ios_contact = 'ios_contact.svg';
  static const String ios_contacts = 'ios_contacts.svg';
  static const String ios_contract = 'ios_contract.svg';
  static const String ios_contrast = 'ios_contrast.svg';
  static const String ios_copy = 'ios_copy.svg';
  static const String ios_create = 'ios_create.svg';
  static const String ios_crop = 'ios_crop.svg';
  static const String ios_cube = 'ios_cube.svg';
  static const String ios_cut = 'ios_cut.svg';
  static const String ios_desktop = 'ios_desktop.svg';
  static const String ios_disc = 'ios_disc.svg';
  static const String ios_document = 'ios_document.svg';
  static const String ios_done_all = 'ios_done_all.svg';
  static const String ios_download = 'ios_download.svg';
  static const String ios_easel = 'ios_easel.svg';
  static const String ios_egg = 'ios_egg.svg';
  static const String ios_exit = 'ios_exit.svg';
  static const String ios_expand = 'ios_expand.svg';
  static const String ios_eye_off = 'ios_eye_off.svg';
  static const String ios_eye = 'ios_eye.svg';
  static const String ios_fastforward = 'ios_fastforward.svg';
  static const String ios_female = 'ios_female.svg';
  static const String ios_filing = 'ios_filing.svg';
  static const String ios_film = 'ios_film.svg';
  static const String ios_finger_print = 'ios_finger_print.svg';
  static const String ios_fitness = 'ios_fitness.svg';
  static const String ios_flag = 'ios_flag.svg';
  static const String ios_flame = 'ios_flame.svg';
  static const String ios_flash_off = 'ios_flash_off.svg';
  static const String ios_flash = 'ios_flash.svg';
  static const String ios_flashlight = 'ios_flashlight.svg';
  static const String ios_flask = 'ios_flask.svg';
  static const String ios_flower = 'ios_flower.svg';
  static const String ios_folder_open = 'ios_folder_open.svg';
  static const String ios_folder = 'ios_folder.svg';
  static const String ios_football = 'ios_football.svg';
  static const String ios_funnel = 'ios_funnel.svg';
  static const String ios_gift = 'ios_gift.svg';
  static const String ios_git_branch = 'ios_git_branch.svg';
  static const String ios_git_commit = 'ios_git_commit.svg';
  static const String ios_git_compare = 'ios_git_compare.svg';
  static const String ios_git_merge = 'ios_git_merge.svg';
  static const String ios_git_network = 'ios_git_network.svg';
  static const String ios_git_pull_request = 'ios_git_pull_request.svg';
  static const String ios_glasses = 'ios_glasses.svg';
  static const String ios_globe = 'ios_globe.svg';
  static const String ios_grid = 'ios_grid.svg';
  static const String ios_hammer = 'ios_hammer.svg';
  static const String ios_hand = 'ios_hand.svg';
  static const String ios_happy = 'ios_happy.svg';
  static const String ios_headset = 'ios_headset.svg';
  static const String ios_heart_dislike = 'ios_heart_dislike.svg';
  static const String ios_heart_empty = 'ios_heart_empty.svg';
  static const String ios_heart_half = 'ios_heart_half.svg';
  static const String ios_heart = 'ios_heart.svg';
  static const String ios_help_buoy = 'ios_help_buoy.svg';
  static const String ios_help_circle_outline = 'ios_help_circle_outline.svg';
  static const String ios_help_circle = 'ios_help_circle.svg';
  static const String ios_help = 'ios_help.svg';
  static const String ios_home = 'ios_home.svg';
  static const String ios_hourglass = 'ios_hourglass.svg';
  static const String ios_ice_cream = 'ios_ice_cream.svg';
  static const String ios_image = 'ios_image.svg';
  static const String ios_images = 'ios_images.svg';
  static const String ios_infinite = 'ios_infinite.svg';
  static const String ios_information_circle_outline = 'ios_information_circle_outline.svg';
  static const String ios_information_circle = 'ios_information_circle.svg';
  static const String ios_information = 'ios_information.svg';
  static const String ios_jet = 'ios_jet.svg';
  static const String ios_journal = 'ios_journal.svg';
  static const String ios_key = 'ios_key.svg';
  static const String ios_keypad = 'ios_keypad.svg';
  static const String ios_laptop = 'ios_laptop.svg';
  static const String ios_leaf = 'ios_leaf.svg';
  static const String ios_link = 'ios_link.svg';
  static const String ios_list_box = 'ios_list_box.svg';
  static const String ios_list = 'ios_list.svg';
  static const String ios_locate = 'ios_locate.svg';
  static const String ios_lock = 'ios_lock.svg';
  static const String ios_log_in = 'ios_log_in.svg';
  static const String ios_log_out = 'ios_log_out.svg';
  static const String ios_magnet = 'ios_magnet.svg';
  static const String ios_mail_open = 'ios_mail_open.svg';
  static const String ios_mail_unread = 'ios_mail_unread.svg';
  static const String ios_mail = 'ios_mail.svg';
  static const String ios_male = 'ios_male.svg';
  static const String ios_man = 'ios_man.svg';
  static const String ios_map = 'ios_map.svg';
  static const String ios_medal = 'ios_medal.svg';
  static const String ios_medical = 'ios_medical.svg';
  static const String ios_medkit = 'ios_medkit.svg';
  static const String ios_megaphone = 'ios_megaphone.svg';
  static const String ios_menu = 'ios_menu.svg';
  static const String ios_mic_off = 'ios_mic_off.svg';
  static const String ios_mic = 'ios_mic.svg';
  static const String ios_microphone = 'ios_microphone.svg';
  static const String ios_moon = 'ios_moon.svg';
  static const String ios_more = 'ios_more.svg';
  static const String ios_move = 'ios_move.svg';
  static const String ios_musical_note = 'ios_musical_note.svg';
  static const String ios_musical_notes = 'ios_musical_notes.svg';
  static const String ios_navigate = 'ios_navigate.svg';
  static const String ios_notifications_off = 'ios_notifications_off.svg';
  static const String ios_notifications_outline = 'ios_notifications_outline.svg';
  static const String ios_notifications = 'ios_notifications.svg';
  static const String ios_nuclear = 'ios_nuclear.svg';
  static const String ios_nutrition = 'ios_nutrition.svg';
  static const String ios_open = 'ios_open.svg';
  static const String ios_options = 'ios_options.svg';
  static const String ios_outlet = 'ios_outlet.svg';
  static const String ios_paper_plane = 'ios_paper_plane.svg';
  static const String ios_paper = 'ios_paper.svg';
  static const String ios_partly_sunny = 'ios_partly_sunny.svg';
  static const String ios_pause = 'ios_pause.svg';
  static const String ios_paw = 'ios_paw.svg';
  static const String ios_people = 'ios_people.svg';
  static const String ios_person_add = 'ios_person_add.svg';
  static const String ios_person = 'ios_person.svg';
  static const String ios_phone_landscape = 'ios_phone_landscape.svg';
  static const String ios_phone_portrait = 'ios_phone_portrait.svg';
  static const String ios_photos = 'ios_photos.svg';
  static const String ios_pie = 'ios_pie.svg';
  static const String ios_pin = 'ios_pin.svg';
  static const String ios_pint = 'ios_pint.svg';
  static const String ios_pizza = 'ios_pizza.svg';
  static const String ios_planet = 'ios_planet.svg';
  static const String ios_play_circle = 'ios_play_circle.svg';
  static const String ios_play = 'ios_play.svg';
  static const String ios_podium = 'ios_podium.svg';
  static const String ios_power = 'ios_power.svg';
  static const String ios_pricetag = 'ios_pricetag.svg';
  static const String ios_pricetags = 'ios_pricetags.svg';
  static const String ios_print = 'ios_print.svg';
  static const String ios_pulse = 'ios_pulse.svg';
  static const String ios_qr_scanner = 'ios_qr_scanner.svg';
  static const String ios_quote = 'ios_quote.svg';
  static const String ios_radio_button_off = 'ios_radio_button_off.svg';
  static const String ios_radio_button_on = 'ios_radio_button_on.svg';
  static const String ios_radio = 'ios_radio.svg';
  static const String ios_rainy = 'ios_rainy.svg';
  static const String ios_recording = 'ios_recording.svg';
  static const String ios_redo = 'ios_redo.svg';
  static const String ios_refresh_circle = 'ios_refresh_circle.svg';
  static const String ios_refresh = 'ios_refresh.svg';
  static const String ios_remove_circle_outline = 'ios_remove_circle_outline.svg';
  static const String ios_remove_circle = 'ios_remove_circle.svg';
  static const String ios_remove = 'ios_remove.svg';
  static const String ios_reorder = 'ios_reorder.svg';
  static const String ios_repeat = 'ios_repeat.svg';
  static const String ios_resize = 'ios_resize.svg';
  static const String ios_restaurant = 'ios_restaurant.svg';
  static const String ios_return_left = 'ios_return_left.svg';
  static const String ios_return_right = 'ios_return_right.svg';
  static const String ios_reverse_camera = 'ios_reverse_camera.svg';
  static const String ios_rewind = 'ios_rewind.svg';
  static const String ios_ribbon = 'ios_ribbon.svg';
  static const String ios_rocket = 'ios_rocket.svg';
  static const String ios_rose = 'ios_rose.svg';
  static const String ios_sad = 'ios_sad.svg';
  static const String ios_save = 'ios_save.svg';
  static const String ios_school = 'ios_school.svg';
  static const String ios_search = 'ios_search.svg';
  static const String ios_send = 'ios_send.svg';
  static const String ios_settings = 'ios_settings.svg';
  static const String ios_share_alt = 'ios_share_alt.svg';
  static const String ios_share = 'ios_share.svg';
  static const String ios_shirt = 'ios_shirt.svg';
  static const String ios_shuffle = 'ios_shuffle.svg';
  static const String ios_skip_backward = 'ios_skip_backward.svg';
  static const String ios_skip_forward = 'ios_skip_forward.svg';
  static const String ios_snow = 'ios_snow.svg';
  static const String ios_speedometer = 'ios_speedometer.svg';
  static const String ios_square_outline = 'ios_square_outline.svg';
  static const String ios_square = 'ios_square.svg';
  static const String ios_star_half = 'ios_star_half.svg';
  static const String ios_star_outline = 'ios_star_outline.svg';
  static const String ios_star = 'ios_star.svg';
  static const String ios_stats = 'ios_stats.svg';
  static const String ios_stopwatch = 'ios_stopwatch.svg';
  static const String ios_subway = 'ios_subway.svg';
  static const String ios_sunny = 'ios_sunny.svg';
  static const String ios_swap = 'ios_swap.svg';
  static const String ios_switch = 'ios_switch.svg';
  static const String ios_sync = 'ios_sync.svg';
  static const String ios_tablet_landscape = 'ios_tablet_landscape.svg';
  static const String ios_tablet_portrait = 'ios_tablet_portrait.svg';
  static const String ios_tennisball = 'ios_tennisball.svg';
  static const String ios_text = 'ios_text.svg';
  static const String ios_thermometer = 'ios_thermometer.svg';
  static const String ios_thumbs_down = 'ios_thumbs_down.svg';
  static const String ios_thumbs_up = 'ios_thumbs_up.svg';
  static const String ios_thunderstorm = 'ios_thunderstorm.svg';
  static const String ios_time = 'ios_time.svg';
  static const String ios_timer = 'ios_timer.svg';
  static const String ios_today = 'ios_today.svg';
  static const String ios_train = 'ios_train.svg';
  static const String ios_transgender = 'ios_transgender.svg';
  static const String ios_trash = 'ios_trash.svg';
  static const String ios_trending_down = 'ios_trending_down.svg';
  static const String ios_trending_up = 'ios_trending_up.svg';
  static const String ios_trophy = 'ios_trophy.svg';
  static const String ios_tv = 'ios_tv.svg';
  static const String ios_umbrella = 'ios_umbrella.svg';
  static const String ios_undo = 'ios_undo.svg';
  static const String ios_unlock = 'ios_unlock.svg';
  static const String ios_videocam = 'ios_videocam.svg';
  static const String ios_volume_high = 'ios_volume_high.svg';
  static const String ios_volume_low = 'ios_volume_low.svg';
  static const String ios_volume_mute = 'ios_volume_mute.svg';
  static const String ios_volume_off = 'ios_volume_off.svg';
  static const String ios_walk = 'ios_walk.svg';
  static const String ios_wallet = 'ios_wallet.svg';
  static const String ios_warning = 'ios_warning.svg';
  static const String ios_watch = 'ios_watch.svg';
  static const String ios_water = 'ios_water.svg';
  static const String ios_wifi = 'ios_wifi.svg';
  static const String ios_wine = 'ios_wine.svg';
  static const String ios_woman = 'ios_woman.svg';
  static const String journal_outline = 'journal_outline.svg';
  static const String journal_sharp = 'journal_sharp.svg';
  static const String journal = 'journal.svg';
  static const String key_outline = 'key_outline.svg';
  static const String key_sharp = 'key_sharp.svg';
  static const String key_ = 'key.svg';
  static const String keypad_outline = 'keypad_outline.svg';
  static const String keypad_sharp = 'keypad_sharp.svg';
  static const String keypad = 'keypad.svg';
  static const String language_outline = 'language_outline.svg';
  static const String language_sharp = 'language_sharp.svg';
  static const String language = 'language.svg';
  static const String laptop_outline = 'laptop_outline.svg';
  static const String laptop_sharp = 'laptop_sharp.svg';
  static const String laptop = 'laptop.svg';
  static const String layers_outline = 'layers_outline.svg';
  static const String layers_sharp = 'layers_sharp.svg';
  static const String layers = 'layers.svg';
  static const String leaf_outline = 'leaf_outline.svg';
  static const String leaf_sharp = 'leaf_sharp.svg';
  static const String leaf = 'leaf.svg';
  static const String library_outline = 'library_outline.svg';
  static const String library_sharp = 'library_sharp.svg';
  static const String library = 'library.svg';
  static const String link_outline = 'link_outline.svg';
  static const String link_sharp = 'link_sharp.svg';
  static const String link = 'link.svg';
  static const String list_circle_outline = 'list_circle_outline.svg';
  static const String list_circle_sharp = 'list_circle_sharp.svg';
  static const String list_circle = 'list_circle.svg';
  static const String list_outline = 'list_outline.svg';
  static const String list_sharp = 'list_sharp.svg';
  static const String list = 'list.svg';
  static const String locate_outline = 'locate_outline.svg';
  static const String locate_sharp = 'locate_sharp.svg';
  static const String locate = 'locate.svg';
  static const String location_outline = 'location_outline.svg';
  static const String location_sharp = 'location_sharp.svg';
  static const String location = 'location.svg';
  static const String lock_closed_outline = 'lock_closed_outline.svg';
  static const String lock_closed_sharp = 'lock_closed_sharp.svg';
  static const String lock_closed = 'lock_closed.svg';
  static const String lock_open_outline = 'lock_open_outline.svg';
  static const String lock_open_sharp = 'lock_open_sharp.svg';
  static const String lock_open = 'lock_open.svg';
  static const String log_in_outline = 'log_in_outline.svg';
  static const String log_in_sharp = 'log_in_sharp.svg';
  static const String log_in = 'log_in.svg';
  static const String log_out_outline = 'log_out_outline.svg';
  static const String log_out_sharp = 'log_out_sharp.svg';
  static const String log_out = 'log_out.svg';
  static const String logo_alipay = 'logo_alipay.svg';
  static const String logo_amazon = 'logo_amazon.svg';
  static const String logo_amplify = 'logo_amplify.svg';
  static const String logo_android = 'logo_android.svg';
  static const String logo_angular = 'logo_angular.svg';
  static const String logo_apple_appstore = 'logo_apple_appstore.svg';
  static const String logo_apple_ar = 'logo_apple_ar.svg';
  static const String logo_apple = 'logo_apple.svg';
  static const String logo_behance = 'logo_behance.svg';
  static const String logo_bitbucket = 'logo_bitbucket.svg';
  static const String logo_bitcoin = 'logo_bitcoin.svg';
  static const String logo_buffer = 'logo_buffer.svg';
  static const String logo_capacitor = 'logo_capacitor.svg';
  static const String logo_chrome = 'logo_chrome.svg';
  static const String logo_closed_captioning = 'logo_closed_captioning.svg';
  static const String logo_codepen = 'logo_codepen.svg';
  static const String logo_css3 = 'logo_css3.svg';
  static const String logo_designernews = 'logo_designernews.svg';
  static const String logo_deviantart = 'logo_deviantart.svg';
  static const String logo_discord = 'logo_discord.svg';
  static const String logo_docker = 'logo_docker.svg';
  static const String logo_dribbble = 'logo_dribbble.svg';
  static const String logo_dropbox = 'logo_dropbox.svg';
  static const String logo_edge = 'logo_edge.svg';
  static const String logo_electron = 'logo_electron.svg';
  static const String logo_euro = 'logo_euro.svg';
  static const String logo_facebook = 'logo_facebook.svg';
  static const String logo_figma = 'logo_figma.svg';
  static const String logo_firebase = 'logo_firebase.svg';
  static const String logo_firefox = 'logo_firefox.svg';
  static const String logo_flickr = 'logo_flickr.svg';
  static const String logo_foursquare = 'logo_foursquare.svg';
  static const String logo_freebsd_devil = 'logo_freebsd_devil.svg';
  static const String logo_game_controller_a = 'logo_game_controller_a.svg';
  static const String logo_game_controller_b = 'logo_game_controller_b.svg';
  static const String logo_github = 'logo_github.svg';
  static const String logo_gitlab = 'logo_gitlab.svg';
  static const String logo_google_playstore = 'logo_google_playstore.svg';
  static const String logo_google = 'logo_google.svg';
  static const String logo_googleplus = 'logo_googleplus.svg';
  static const String logo_hackernews = 'logo_hackernews.svg';
  static const String logo_html5 = 'logo_html5.svg';
  static const String logo_instagram = 'logo_instagram.svg';
  static const String logo_ionic = 'logo_ionic.svg';
  static const String logo_ionitron = 'logo_ionitron.svg';
  static const String logo_javascript = 'logo_javascript.svg';
  static const String logo_laravel = 'logo_laravel.svg';
  static const String logo_linkedin = 'logo_linkedin.svg';
  static const String logo_markdown = 'logo_markdown.svg';
  static const String logo_mastodon = 'logo_mastodon.svg';
  static const String logo_medium = 'logo_medium.svg';
  static const String logo_microsoft = 'logo_microsoft.svg';
  static const String logo_model_s = 'logo_model_s.svg';
  static const String logo_no_smoking = 'logo_no_smoking.svg';
  static const String logo_nodejs = 'logo_nodejs.svg';
  static const String logo_npm = 'logo_npm.svg';
  static const String logo_octocat = 'logo_octocat.svg';
  static const String logo_paypal = 'logo_paypal.svg';
  static const String logo_pinterest = 'logo_pinterest.svg';
  static const String logo_playstation = 'logo_playstation.svg';
  static const String logo_polymer = 'logo_polymer.svg';
  static const String logo_pwa = 'logo_pwa.svg';
  static const String logo_python = 'logo_python.svg';
  static const String logo_react = 'logo_react.svg';
  static const String logo_reddit = 'logo_reddit.svg';
  static const String logo_rss = 'logo_rss.svg';
  static const String logo_sass = 'logo_sass.svg';
  static const String logo_skype = 'logo_skype.svg';
  static const String logo_slack = 'logo_slack.svg';
  static const String logo_snapchat = 'logo_snapchat.svg';
  static const String logo_soundcloud = 'logo_soundcloud.svg';
  static const String logo_stackoverflow = 'logo_stackoverflow.svg';
  static const String logo_steam = 'logo_steam.svg';
  static const String logo_stencil = 'logo_stencil.svg';
  static const String logo_tableau = 'logo_tableau.svg';
  static const String logo_tiktok = 'logo_tiktok.svg';
  static const String logo_tumblr = 'logo_tumblr.svg';
  static const String logo_tux = 'logo_tux.svg';
  static const String logo_twitch = 'logo_twitch.svg';
  static const String logo_twitter = 'logo_twitter.svg';
  static const String logo_usd = 'logo_usd.svg';
  static const String logo_venmo = 'logo_venmo.svg';
  static const String logo_vercel = 'logo_vercel.svg';
  static const String logo_vimeo = 'logo_vimeo.svg';
  static const String logo_vk = 'logo_vk.svg';
  static const String logo_vue = 'logo_vue.svg';
  static const String logo_web_component = 'logo_web_component.svg';
  static const String logo_wechat = 'logo_wechat.svg';
  static const String logo_whatsapp = 'logo_whatsapp.svg';
  static const String logo_windows = 'logo_windows.svg';
  static const String logo_wordpress = 'logo_wordpress.svg';
  static const String logo_xbox = 'logo_xbox.svg';
  static const String logo_xing = 'logo_xing.svg';
  static const String logo_yahoo = 'logo_yahoo.svg';
  static const String logo_yen = 'logo_yen.svg';
  static const String logo_youtube = 'logo_youtube.svg';
  static const String magnet_outline = 'magnet_outline.svg';
  static const String magnet_sharp = 'magnet_sharp.svg';
  static const String magnet = 'magnet.svg';
  static const String mail_open_outline = 'mail_open_outline.svg';
  static const String mail_open_sharp = 'mail_open_sharp.svg';
  static const String mail_open = 'mail_open.svg';
  static const String mail_outline = 'mail_outline.svg';
  static const String mail_sharp = 'mail_sharp.svg';
  static const String mail_unread_outline = 'mail_unread_outline.svg';
  static const String mail_unread_sharp = 'mail_unread_sharp.svg';
  static const String mail_unread = 'mail_unread.svg';
  static const String mail = 'mail.svg';
  static const String male_female_outline = 'male_female_outline.svg';
  static const String male_female_sharp = 'male_female_sharp.svg';
  static const String male_female = 'male_female.svg';
  static const String male_outline = 'male_outline.svg';
  static const String male_sharp = 'male_sharp.svg';
  static const String male = 'male.svg';
  static const String man_outline = 'man_outline.svg';
  static const String man_sharp = 'man_sharp.svg';
  static const String man = 'man.svg';
  static const String map_outline = 'map_outline.svg';
  static const String map_sharp = 'map_sharp.svg';
  static const String map = 'map.svg';
  static const String md_add_circle_outline = 'md_add_circle_outline.svg';
  static const String md_add_circle = 'md_add_circle.svg';
  static const String md_add = 'md_add.svg';
  static const String md_airplane = 'md_airplane.svg';
  static const String md_alarm = 'md_alarm.svg';
  static const String md_albums = 'md_albums.svg';
  static const String md_alert = 'md_alert.svg';
  static const String md_american_football = 'md_american_football.svg';
  static const String md_analytics = 'md_analytics.svg';
  static const String md_aperture = 'md_aperture.svg';
  static const String md_apps = 'md_apps.svg';
  static const String md_appstore = 'md_appstore.svg';
  static const String md_archive = 'md_archive.svg';
  static const String md_arrow_back = 'md_arrow_back.svg';
  static const String md_arrow_down = 'md_arrow_down.svg';
  static const String md_arrow_dropdown_circle = 'md_arrow_dropdown_circle.svg';
  static const String md_arrow_dropdown = 'md_arrow_dropdown.svg';
  static const String md_arrow_dropleft_circle = 'md_arrow_dropleft_circle.svg';
  static const String md_arrow_dropleft = 'md_arrow_dropleft.svg';
  static const String md_arrow_dropright_circle = 'md_arrow_dropright_circle.svg';
  static const String md_arrow_dropright = 'md_arrow_dropright.svg';
  static const String md_arrow_dropup_circle = 'md_arrow_dropup_circle.svg';
  static const String md_arrow_dropup = 'md_arrow_dropup.svg';
  static const String md_arrow_forward = 'md_arrow_forward.svg';
  static const String md_arrow_round_back = 'md_arrow_round_back.svg';
  static const String md_arrow_round_down = 'md_arrow_round_down.svg';
  static const String md_arrow_round_forward = 'md_arrow_round_forward.svg';
  static const String md_arrow_round_up = 'md_arrow_round_up.svg';
  static const String md_arrow_up = 'md_arrow_up.svg';
  static const String md_at = 'md_at.svg';
  static const String md_attach = 'md_attach.svg';
  static const String md_backspace = 'md_backspace.svg';
  static const String md_barcode = 'md_barcode.svg';
  static const String md_baseball = 'md_baseball.svg';
  static const String md_basket = 'md_basket.svg';
  static const String md_basketball = 'md_basketball.svg';
  static const String md_battery_charging = 'md_battery_charging.svg';
  static const String md_battery_dead = 'md_battery_dead.svg';
  static const String md_battery_full = 'md_battery_full.svg';
  static const String md_beaker = 'md_beaker.svg';
  static const String md_bed = 'md_bed.svg';
  static const String md_beer = 'md_beer.svg';
  static const String md_bicycle = 'md_bicycle.svg';
  static const String md_bluetooth = 'md_bluetooth.svg';
  static const String md_boat = 'md_boat.svg';
  static const String md_body = 'md_body.svg';
  static const String md_bonfire = 'md_bonfire.svg';
  static const String md_book = 'md_book.svg';
  static const String md_bookmark = 'md_bookmark.svg';
  static const String md_bookmarks = 'md_bookmarks.svg';
  static const String md_bowtie = 'md_bowtie.svg';
  static const String md_briefcase = 'md_briefcase.svg';
  static const String md_browsers = 'md_browsers.svg';
  static const String md_brush = 'md_brush.svg';
  static const String md_bug = 'md_bug.svg';
  static const String md_build = 'md_build.svg';
  static const String md_bulb = 'md_bulb.svg';
  static const String md_bus = 'md_bus.svg';
  static const String md_business = 'md_business.svg';
  static const String md_cafe = 'md_cafe.svg';
  static const String md_calculator = 'md_calculator.svg';
  static const String md_calendar = 'md_calendar.svg';
  static const String md_call = 'md_call.svg';
  static const String md_camera = 'md_camera.svg';
  static const String md_car = 'md_car.svg';
  static const String md_card = 'md_card.svg';
  static const String md_cart = 'md_cart.svg';
  static const String md_cash = 'md_cash.svg';
  static const String md_cellular = 'md_cellular.svg';
  static const String md_chatboxes = 'md_chatboxes.svg';
  static const String md_chatbubbles = 'md_chatbubbles.svg';
  static const String md_checkbox_outline = 'md_checkbox_outline.svg';
  static const String md_checkbox = 'md_checkbox.svg';
  static const String md_checkmark_circle_outline = 'md_checkmark_circle_outline.svg';
  static const String md_checkmark_circle = 'md_checkmark_circle.svg';
  static const String md_checkmark = 'md_checkmark.svg';
  static const String md_clipboard = 'md_clipboard.svg';
  static const String md_clock = 'md_clock.svg';
  static const String md_close_circle_outline = 'md_close_circle_outline.svg';
  static const String md_close_circle = 'md_close_circle.svg';
  static const String md_close = 'md_close.svg';
  static const String md_cloud_circle = 'md_cloud_circle.svg';
  static const String md_cloud_done = 'md_cloud_done.svg';
  static const String md_cloud_download = 'md_cloud_download.svg';
  static const String md_cloud_outline = 'md_cloud_outline.svg';
  static const String md_cloud_upload = 'md_cloud_upload.svg';
  static const String md_cloud = 'md_cloud.svg';
  static const String md_cloudy_night = 'md_cloudy_night.svg';
  static const String md_cloudy = 'md_cloudy.svg';
  static const String md_code_download = 'md_code_download.svg';
  static const String md_code_working = 'md_code_working.svg';
  static const String md_code = 'md_code.svg';
  static const String md_cog = 'md_cog.svg';
  static const String md_color_fill = 'md_color_fill.svg';
  static const String md_color_filter = 'md_color_filter.svg';
  static const String md_color_palette = 'md_color_palette.svg';
  static const String md_color_wand = 'md_color_wand.svg';
  static const String md_compass = 'md_compass.svg';
  static const String md_construct = 'md_construct.svg';
  static const String md_contact = 'md_contact.svg';
  static const String md_contacts = 'md_contacts.svg';
  static const String md_contract = 'md_contract.svg';
  static const String md_contrast = 'md_contrast.svg';
  static const String md_copy = 'md_copy.svg';
  static const String md_create = 'md_create.svg';
  static const String md_crop = 'md_crop.svg';
  static const String md_cube = 'md_cube.svg';
  static const String md_cut = 'md_cut.svg';
  static const String md_desktop = 'md_desktop.svg';
  static const String md_disc = 'md_disc.svg';
  static const String md_document = 'md_document.svg';
  static const String md_done_all = 'md_done_all.svg';
  static const String md_download = 'md_download.svg';
  static const String md_easel = 'md_easel.svg';
  static const String md_egg = 'md_egg.svg';
  static const String md_exit = 'md_exit.svg';
  static const String md_expand = 'md_expand.svg';
  static const String md_eye_off = 'md_eye_off.svg';
  static const String md_eye = 'md_eye.svg';
  static const String md_fastforward = 'md_fastforward.svg';
  static const String md_female = 'md_female.svg';
  static const String md_filing = 'md_filing.svg';
  static const String md_film = 'md_film.svg';
  static const String md_finger_print = 'md_finger_print.svg';
  static const String md_fitness = 'md_fitness.svg';
  static const String md_flag = 'md_flag.svg';
  static const String md_flame = 'md_flame.svg';
  static const String md_flash_off = 'md_flash_off.svg';
  static const String md_flash = 'md_flash.svg';
  static const String md_flashlight = 'md_flashlight.svg';
  static const String md_flask = 'md_flask.svg';
  static const String md_flower = 'md_flower.svg';
  static const String md_folder_open = 'md_folder_open.svg';
  static const String md_folder = 'md_folder.svg';
  static const String md_football = 'md_football.svg';
  static const String md_funnel = 'md_funnel.svg';
  static const String md_gift = 'md_gift.svg';
  static const String md_git_branch = 'md_git_branch.svg';
  static const String md_git_commit = 'md_git_commit.svg';
  static const String md_git_compare = 'md_git_compare.svg';
  static const String md_git_merge = 'md_git_merge.svg';
  static const String md_git_network = 'md_git_network.svg';
  static const String md_git_pull_request = 'md_git_pull_request.svg';
  static const String md_glasses = 'md_glasses.svg';
  static const String md_globe = 'md_globe.svg';
  static const String md_grid = 'md_grid.svg';
  static const String md_hammer = 'md_hammer.svg';
  static const String md_hand = 'md_hand.svg';
  static const String md_happy = 'md_happy.svg';
  static const String md_headset = 'md_headset.svg';
  static const String md_heart_dislike = 'md_heart_dislike.svg';
  static const String md_heart_empty = 'md_heart_empty.svg';
  static const String md_heart_half = 'md_heart_half.svg';
  static const String md_heart = 'md_heart.svg';
  static const String md_help_buoy = 'md_help_buoy.svg';
  static const String md_help_circle_outline = 'md_help_circle_outline.svg';
  static const String md_help_circle = 'md_help_circle.svg';
  static const String md_help = 'md_help.svg';
  static const String md_home = 'md_home.svg';
  static const String md_hourglass = 'md_hourglass.svg';
  static const String md_ice_cream = 'md_ice_cream.svg';
  static const String md_image = 'md_image.svg';
  static const String md_images = 'md_images.svg';
  static const String md_infinite = 'md_infinite.svg';
  static const String md_information_circle_outline = 'md_information_circle_outline.svg';
  static const String md_information_circle = 'md_information_circle.svg';
  static const String md_information = 'md_information.svg';
  static const String md_jet = 'md_jet.svg';
  static const String md_journal = 'md_journal.svg';
  static const String md_key = 'md_key.svg';
  static const String md_keypad = 'md_keypad.svg';
  static const String md_laptop = 'md_laptop.svg';
  static const String md_leaf = 'md_leaf.svg';
  static const String md_link = 'md_link.svg';
  static const String md_list_box = 'md_list_box.svg';
  static const String md_list = 'md_list.svg';
  static const String md_locate = 'md_locate.svg';
  static const String md_lock = 'md_lock.svg';
  static const String md_log_in = 'md_log_in.svg';
  static const String md_log_out = 'md_log_out.svg';
  static const String md_magnet = 'md_magnet.svg';
  static const String md_mail_open = 'md_mail_open.svg';
  static const String md_mail_unread = 'md_mail_unread.svg';
  static const String md_mail = 'md_mail.svg';
  static const String md_male = 'md_male.svg';
  static const String md_man = 'md_man.svg';
  static const String md_map = 'md_map.svg';
  static const String md_medal = 'md_medal.svg';
  static const String md_medical = 'md_medical.svg';
  static const String md_medkit = 'md_medkit.svg';
  static const String md_megaphone = 'md_megaphone.svg';
  static const String md_menu = 'md_menu.svg';
  static const String md_mic_off = 'md_mic_off.svg';
  static const String md_mic = 'md_mic.svg';
  static const String md_microphone = 'md_microphone.svg';
  static const String md_moon = 'md_moon.svg';
  static const String md_more = 'md_more.svg';
  static const String md_move = 'md_move.svg';
  static const String md_musical_note = 'md_musical_note.svg';
  static const String md_musical_notes = 'md_musical_notes.svg';
  static const String md_navigate = 'md_navigate.svg';
  static const String md_notifications_off = 'md_notifications_off.svg';
  static const String md_notifications_outline = 'md_notifications_outline.svg';
  static const String md_notifications = 'md_notifications.svg';
  static const String md_nuclear = 'md_nuclear.svg';
  static const String md_nutrition = 'md_nutrition.svg';
  static const String md_open = 'md_open.svg';
  static const String md_options = 'md_options.svg';
  static const String md_outlet = 'md_outlet.svg';
  static const String md_paper_plane = 'md_paper_plane.svg';
  static const String md_paper = 'md_paper.svg';
  static const String md_partly_sunny = 'md_partly_sunny.svg';
  static const String md_pause = 'md_pause.svg';
  static const String md_paw = 'md_paw.svg';
  static const String md_people = 'md_people.svg';
  static const String md_person_add = 'md_person_add.svg';
  static const String md_person = 'md_person.svg';
  static const String md_phone_landscape = 'md_phone_landscape.svg';
  static const String md_phone_portrait = 'md_phone_portrait.svg';
  static const String md_photos = 'md_photos.svg';
  static const String md_pie = 'md_pie.svg';
  static const String md_pin = 'md_pin.svg';
  static const String md_pint = 'md_pint.svg';
  static const String md_pizza = 'md_pizza.svg';
  static const String md_planet = 'md_planet.svg';
  static const String md_play_circle = 'md_play_circle.svg';
  static const String md_play = 'md_play.svg';
  static const String md_podium = 'md_podium.svg';
  static const String md_power = 'md_power.svg';
  static const String md_pricetag = 'md_pricetag.svg';
  static const String md_pricetags = 'md_pricetags.svg';
  static const String md_print = 'md_print.svg';
  static const String md_pulse = 'md_pulse.svg';
  static const String md_qr_scanner = 'md_qr_scanner.svg';
  static const String md_quote = 'md_quote.svg';
  static const String md_radio_button_off = 'md_radio_button_off.svg';
  static const String md_radio_button_on = 'md_radio_button_on.svg';
  static const String md_radio = 'md_radio.svg';
  static const String md_rainy = 'md_rainy.svg';
  static const String md_recording = 'md_recording.svg';
  static const String md_redo = 'md_redo.svg';
  static const String md_refresh_circle = 'md_refresh_circle.svg';
  static const String md_refresh = 'md_refresh.svg';
  static const String md_remove_circle_outline = 'md_remove_circle_outline.svg';
  static const String md_remove_circle = 'md_remove_circle.svg';
  static const String md_remove = 'md_remove.svg';
  static const String md_reorder = 'md_reorder.svg';
  static const String md_repeat = 'md_repeat.svg';
  static const String md_resize = 'md_resize.svg';
  static const String md_restaurant = 'md_restaurant.svg';
  static const String md_return_left = 'md_return_left.svg';
  static const String md_return_right = 'md_return_right.svg';
  static const String md_reverse_camera = 'md_reverse_camera.svg';
  static const String md_rewind = 'md_rewind.svg';
  static const String md_ribbon = 'md_ribbon.svg';
  static const String md_rocket = 'md_rocket.svg';
  static const String md_rose = 'md_rose.svg';
  static const String md_sad = 'md_sad.svg';
  static const String md_save = 'md_save.svg';
  static const String md_school = 'md_school.svg';
  static const String md_search = 'md_search.svg';
  static const String md_send = 'md_send.svg';
  static const String md_settings = 'md_settings.svg';
  static const String md_share_alt = 'md_share_alt.svg';
  static const String md_share = 'md_share.svg';
  static const String md_shirt = 'md_shirt.svg';
  static const String md_shuffle = 'md_shuffle.svg';
  static const String md_skip_backward = 'md_skip_backward.svg';
  static const String md_skip_forward = 'md_skip_forward.svg';
  static const String md_snow = 'md_snow.svg';
  static const String md_speedometer = 'md_speedometer.svg';
  static const String md_square_outline = 'md_square_outline.svg';
  static const String md_square = 'md_square.svg';
  static const String md_star_half = 'md_star_half.svg';
  static const String md_star_outline = 'md_star_outline.svg';
  static const String md_star = 'md_star.svg';
  static const String md_stats = 'md_stats.svg';
  static const String md_stopwatch = 'md_stopwatch.svg';
  static const String md_subway = 'md_subway.svg';
  static const String md_sunny = 'md_sunny.svg';
  static const String md_swap = 'md_swap.svg';
  static const String md_switch = 'md_switch.svg';
  static const String md_sync = 'md_sync.svg';
  static const String md_tablet_landscape = 'md_tablet_landscape.svg';
  static const String md_tablet_portrait = 'md_tablet_portrait.svg';
  static const String md_tennisball = 'md_tennisball.svg';
  static const String md_text = 'md_text.svg';
  static const String md_thermometer = 'md_thermometer.svg';
  static const String md_thumbs_down = 'md_thumbs_down.svg';
  static const String md_thumbs_up = 'md_thumbs_up.svg';
  static const String md_thunderstorm = 'md_thunderstorm.svg';
  static const String md_time = 'md_time.svg';
  static const String md_timer = 'md_timer.svg';
  static const String md_today = 'md_today.svg';
  static const String md_train = 'md_train.svg';
  static const String md_transgender = 'md_transgender.svg';
  static const String md_trash = 'md_trash.svg';
  static const String md_trending_down = 'md_trending_down.svg';
  static const String md_trending_up = 'md_trending_up.svg';
  static const String md_trophy = 'md_trophy.svg';
  static const String md_tv = 'md_tv.svg';
  static const String md_umbrella = 'md_umbrella.svg';
  static const String md_undo = 'md_undo.svg';
  static const String md_unlock = 'md_unlock.svg';
  static const String md_videocam = 'md_videocam.svg';
  static const String md_volume_high = 'md_volume_high.svg';
  static const String md_volume_low = 'md_volume_low.svg';
  static const String md_volume_mute = 'md_volume_mute.svg';
  static const String md_volume_off = 'md_volume_off.svg';
  static const String md_walk = 'md_walk.svg';
  static const String md_wallet = 'md_wallet.svg';
  static const String md_warning = 'md_warning.svg';
  static const String md_watch = 'md_watch.svg';
  static const String md_water = 'md_water.svg';
  static const String md_wifi = 'md_wifi.svg';
  static const String md_wine = 'md_wine.svg';
  static const String md_woman = 'md_woman.svg';
  static const String medal_outline = 'medal_outline.svg';
  static const String medal_sharp = 'medal_sharp.svg';
  static const String medal = 'medal.svg';
  static const String medical_outline = 'medical_outline.svg';
  static const String medical_sharp = 'medical_sharp.svg';
  static const String medical = 'medical.svg';
  static const String medkit_outline = 'medkit_outline.svg';
  static const String medkit_sharp = 'medkit_sharp.svg';
  static const String medkit = 'medkit.svg';
  static const String megaphone_outline = 'megaphone_outline.svg';
  static const String megaphone_sharp = 'megaphone_sharp.svg';
  static const String megaphone = 'megaphone.svg';
  static const String menu_outline = 'menu_outline.svg';
  static const String menu_sharp = 'menu_sharp.svg';
  static const String menu = 'menu.svg';
  static const String mic_circle_outline = 'mic_circle_outline.svg';
  static const String mic_circle_sharp = 'mic_circle_sharp.svg';
  static const String mic_circle = 'mic_circle.svg';
  static const String mic_off_circle_outline = 'mic_off_circle_outline.svg';
  static const String mic_off_circle_sharp = 'mic_off_circle_sharp.svg';
  static const String mic_off_circle = 'mic_off_circle.svg';
  static const String mic_off_outline = 'mic_off_outline.svg';
  static const String mic_off_sharp = 'mic_off_sharp.svg';
  static const String mic_off = 'mic_off.svg';
  static const String mic_outline = 'mic_outline.svg';
  static const String mic_sharp = 'mic_sharp.svg';
  static const String mic = 'mic.svg';
  static const String moon_outline = 'moon_outline.svg';
  static const String moon_sharp = 'moon_sharp.svg';
  static const String moon = 'moon.svg';
  static const String move_outline = 'move_outline.svg';
  static const String move_sharp = 'move_sharp.svg';
  static const String move = 'move.svg';
  static const String musical_note_outline = 'musical_note_outline.svg';
  static const String musical_note_sharp = 'musical_note_sharp.svg';
  static const String musical_note = 'musical_note.svg';
  static const String musical_notes_outline = 'musical_notes_outline.svg';
  static const String musical_notes_sharp = 'musical_notes_sharp.svg';
  static const String musical_notes = 'musical_notes.svg';
  static const String navigate_circle_outline = 'navigate_circle_outline.svg';
  static const String navigate_circle_sharp = 'navigate_circle_sharp.svg';
  static const String navigate_circle = 'navigate_circle.svg';
  static const String navigate_outline = 'navigate_outline.svg';
  static const String navigate_sharp = 'navigate_sharp.svg';
  static const String navigate = 'navigate.svg';
  static const String newspaper_outline = 'newspaper_outline.svg';
  static const String newspaper_sharp = 'newspaper_sharp.svg';
  static const String newspaper = 'newspaper.svg';
  static const String notifications_circle_outline = 'notifications_circle_outline.svg';
  static const String notifications_circle_sharp = 'notifications_circle_sharp.svg';
  static const String notifications_circle = 'notifications_circle.svg';
  static const String notifications_off_circle_outline = 'notifications_off_circle_outline.svg';
  static const String notifications_off_circle_sharp = 'notifications_off_circle_sharp.svg';
  static const String notifications_off_circle = 'notifications_off_circle.svg';
  static const String notifications_off_outline = 'notifications_off_outline.svg';
  static const String notifications_off_sharp = 'notifications_off_sharp.svg';
  static const String notifications_off = 'notifications_off.svg';
  static const String notifications_outline = 'notifications_outline.svg';
  static const String notifications_sharp = 'notifications_sharp.svg';
  static const String notifications = 'notifications.svg';
  static const String nuclear_outline = 'nuclear_outline.svg';
  static const String nuclear_sharp = 'nuclear_sharp.svg';
  static const String nuclear = 'nuclear.svg';
  static const String nutrition_outline = 'nutrition_outline.svg';
  static const String nutrition_sharp = 'nutrition_sharp.svg';
  static const String nutrition = 'nutrition.svg';
  static const String open_outline = 'open_outline.svg';
  static const String open_sharp = 'open_sharp.svg';
  static const String open = 'open.svg';
  static const String options_outline = 'options_outline.svg';
  static const String options_sharp = 'options_sharp.svg';
  static const String options = 'options.svg';
  static const String paper_plane_outline = 'paper_plane_outline.svg';
  static const String paper_plane_sharp = 'paper_plane_sharp.svg';
  static const String paper_plane = 'paper_plane.svg';
  static const String partly_sunny_outline = 'partly_sunny_outline.svg';
  static const String partly_sunny_sharp = 'partly_sunny_sharp.svg';
  static const String partly_sunny = 'partly_sunny.svg';
  static const String pause_circle_outline = 'pause_circle_outline.svg';
  static const String pause_circle_sharp = 'pause_circle_sharp.svg';
  static const String pause_circle = 'pause_circle.svg';
  static const String pause_outline = 'pause_outline.svg';
  static const String pause_sharp = 'pause_sharp.svg';
  static const String pause = 'pause.svg';
  static const String paw_outline = 'paw_outline.svg';
  static const String paw_sharp = 'paw_sharp.svg';
  static const String paw = 'paw.svg';
  static const String pencil_outline = 'pencil_outline.svg';
  static const String pencil_sharp = 'pencil_sharp.svg';
  static const String pencil = 'pencil.svg';
  static const String people_circle_outline = 'people_circle_outline.svg';
  static const String people_circle_sharp = 'people_circle_sharp.svg';
  static const String people_circle = 'people_circle.svg';
  static const String people_outline = 'people_outline.svg';
  static const String people_sharp = 'people_sharp.svg';
  static const String people = 'people.svg';
  static const String person_add_outline = 'person_add_outline.svg';
  static const String person_add_sharp = 'person_add_sharp.svg';
  static const String person_add = 'person_add.svg';
  static const String person_circle_outline = 'person_circle_outline.svg';
  static const String person_circle_sharp = 'person_circle_sharp.svg';
  static const String person_circle = 'person_circle.svg';
  static const String person_outline = 'person_outline.svg';
  static const String person_remove_outline = 'person_remove_outline.svg';
  static const String person_remove_sharp = 'person_remove_sharp.svg';
  static const String person_remove = 'person_remove.svg';
  static const String person_sharp = 'person_sharp.svg';
  static const String person = 'person.svg';
  static const String phone_landscape_outline = 'phone_landscape_outline.svg';
  static const String phone_landscape_sharp = 'phone_landscape_sharp.svg';
  static const String phone_landscape = 'phone_landscape.svg';
  static const String phone_portrait_outline = 'phone_portrait_outline.svg';
  static const String phone_portrait_sharp = 'phone_portrait_sharp.svg';
  static const String phone_portrait = 'phone_portrait.svg';
  static const String pie_chart_outline = 'pie_chart_outline.svg';
  static const String pie_chart_sharp = 'pie_chart_sharp.svg';
  static const String pie_chart = 'pie_chart.svg';
  static const String pin_outline = 'pin_outline.svg';
  static const String pin_sharp = 'pin_sharp.svg';
  static const String pin = 'pin.svg';
  static const String pint_outline = 'pint_outline.svg';
  static const String pint_sharp = 'pint_sharp.svg';
  static const String pint = 'pint.svg';
  static const String pizza_outline = 'pizza_outline.svg';
  static const String pizza_sharp = 'pizza_sharp.svg';
  static const String pizza = 'pizza.svg';
  static const String planet_outline = 'planet_outline.svg';
  static const String planet_sharp = 'planet_sharp.svg';
  static const String planet = 'planet.svg';
  static const String play_back_circle_outline = 'play_back_circle_outline.svg';
  static const String play_back_circle_sharp = 'play_back_circle_sharp.svg';
  static const String play_back_circle = 'play_back_circle.svg';
  static const String play_back_outline = 'play_back_outline.svg';
  static const String play_back_sharp = 'play_back_sharp.svg';
  static const String play_back = 'play_back.svg';
  static const String play_circle_outline = 'play_circle_outline.svg';
  static const String play_circle_sharp = 'play_circle_sharp.svg';
  static const String play_circle = 'play_circle.svg';
  static const String play_forward_circle_outline = 'play_forward_circle_outline.svg';
  static const String play_forward_circle_sharp = 'play_forward_circle_sharp.svg';
  static const String play_forward_circle = 'play_forward_circle.svg';
  static const String play_forward_outline = 'play_forward_outline.svg';
  static const String play_forward_sharp = 'play_forward_sharp.svg';
  static const String play_forward = 'play_forward.svg';
  static const String play_outline = 'play_outline.svg';
  static const String play_sharp = 'play_sharp.svg';
  static const String play_skip_back_circle_outline = 'play_skip_back_circle_outline.svg';
  static const String play_skip_back_circle_sharp = 'play_skip_back_circle_sharp.svg';
  static const String play_skip_back_circle = 'play_skip_back_circle.svg';
  static const String play_skip_back_outline = 'play_skip_back_outline.svg';
  static const String play_skip_back_sharp = 'play_skip_back_sharp.svg';
  static const String play_skip_back = 'play_skip_back.svg';
  static const String play_skip_forward_circle_outline = 'play_skip_forward_circle_outline.svg';
  static const String play_skip_forward_circle_sharp = 'play_skip_forward_circle_sharp.svg';
  static const String play_skip_forward_circle = 'play_skip_forward_circle.svg';
  static const String play_skip_forward_outline = 'play_skip_forward_outline.svg';
  static const String play_skip_forward_sharp = 'play_skip_forward_sharp.svg';
  static const String play_skip_forward = 'play_skip_forward.svg';
  static const String play = 'play.svg';
  static const String podium_outline = 'podium_outline.svg';
  static const String podium_sharp = 'podium_sharp.svg';
  static const String podium = 'podium.svg';
  static const String power_outline = 'power_outline.svg';
  static const String power_sharp = 'power_sharp.svg';
  static const String power = 'power.svg';
  static const String pricetag_outline = 'pricetag_outline.svg';
  static const String pricetag_sharp = 'pricetag_sharp.svg';
  static const String pricetag = 'pricetag.svg';
  static const String pricetags_outline = 'pricetags_outline.svg';
  static const String pricetags_sharp = 'pricetags_sharp.svg';
  static const String pricetags = 'pricetags.svg';
  static const String print_outline = 'print_outline.svg';
  static const String print_sharp = 'print_sharp.svg';
  static const String print = 'print.svg';
  static const String prism_outline = 'prism_outline.svg';
  static const String prism_sharp = 'prism_sharp.svg';
  static const String prism = 'prism.svg';
  static const String pulse_outline = 'pulse_outline.svg';
  static const String pulse_sharp = 'pulse_sharp.svg';
  static const String pulse = 'pulse.svg';
  static const String push_outline = 'push_outline.svg';
  static const String push_sharp = 'push_sharp.svg';
  static const String push = 'push.svg';
  static const String qr_code_outline = 'qr_code_outline.svg';
  static const String qr_code_sharp = 'qr_code_sharp.svg';
  static const String qr_code = 'qr_code.svg';
  static const String radio_button_off_outline = 'radio_button_off_outline.svg';
  static const String radio_button_off_sharp = 'radio_button_off_sharp.svg';
  static const String radio_button_off = 'radio_button_off.svg';
  static const String radio_button_on_outline = 'radio_button_on_outline.svg';
  static const String radio_button_on_sharp = 'radio_button_on_sharp.svg';
  static const String radio_button_on = 'radio_button_on.svg';
  static const String radio_outline = 'radio_outline.svg';
  static const String radio_sharp = 'radio_sharp.svg';
  static const String radio = 'radio.svg';
  static const String rainy_outline = 'rainy_outline.svg';
  static const String rainy_sharp = 'rainy_sharp.svg';
  static const String rainy = 'rainy.svg';
  static const String reader_outline = 'reader_outline.svg';
  static const String reader_sharp = 'reader_sharp.svg';
  static const String reader = 'reader.svg';
  static const String receipt_outline = 'receipt_outline.svg';
  static const String receipt_sharp = 'receipt_sharp.svg';
  static const String receipt = 'receipt.svg';
  static const String recording_outline = 'recording_outline.svg';
  static const String recording_sharp = 'recording_sharp.svg';
  static const String recording = 'recording.svg';
  static const String refresh_circle_outline = 'refresh_circle_outline.svg';
  static const String refresh_circle_sharp = 'refresh_circle_sharp.svg';
  static const String refresh_circle = 'refresh_circle.svg';
  static const String refresh_outline = 'refresh_outline.svg';
  static const String refresh_sharp = 'refresh_sharp.svg';
  static const String refresh = 'refresh.svg';
  static const String reload_circle_outline = 'reload_circle_outline.svg';
  static const String reload_circle_sharp = 'reload_circle_sharp.svg';
  static const String reload_circle = 'reload_circle.svg';
  static const String reload_outline = 'reload_outline.svg';
  static const String reload_sharp = 'reload_sharp.svg';
  static const String reload = 'reload.svg';
  static const String remove_circle_outline = 'remove_circle_outline.svg';
  static const String remove_circle_sharp = 'remove_circle_sharp.svg';
  static const String remove_circle = 'remove_circle.svg';
  static const String remove_outline = 'remove_outline.svg';
  static const String remove_sharp = 'remove_sharp.svg';
  static const String remove = 'remove.svg';
  static const String reorder_four_outline = 'reorder_four_outline.svg';
  static const String reorder_four_sharp = 'reorder_four_sharp.svg';
  static const String reorder_four = 'reorder_four.svg';
  static const String reorder_three_outline = 'reorder_three_outline.svg';
  static const String reorder_three_sharp = 'reorder_three_sharp.svg';
  static const String reorder_three = 'reorder_three.svg';
  static const String reorder_two_outline = 'reorder_two_outline.svg';
  static const String reorder_two_sharp = 'reorder_two_sharp.svg';
  static const String reorder_two = 'reorder_two.svg';
  static const String repeat_outline = 'repeat_outline.svg';
  static const String repeat_sharp = 'repeat_sharp.svg';
  static const String repeat = 'repeat.svg';
  static const String resize_outline = 'resize_outline.svg';
  static const String resize_sharp = 'resize_sharp.svg';
  static const String resize = 'resize.svg';
  static const String restaurant_outline = 'restaurant_outline.svg';
  static const String restaurant_sharp = 'restaurant_sharp.svg';
  static const String restaurant = 'restaurant.svg';
  static const String return_down_back_outline = 'return_down_back_outline.svg';
  static const String return_down_back_sharp = 'return_down_back_sharp.svg';
  static const String return_down_back = 'return_down_back.svg';
  static const String return_down_forward_outline = 'return_down_forward_outline.svg';
  static const String return_down_forward_sharp = 'return_down_forward_sharp.svg';
  static const String return_down_forward = 'return_down_forward.svg';
  static const String return_up_back_outline = 'return_up_back_outline.svg';
  static const String return_up_back_sharp = 'return_up_back_sharp.svg';
  static const String return_up_back = 'return_up_back.svg';
  static const String return_up_forward_outline = 'return_up_forward_outline.svg';
  static const String return_up_forward_sharp = 'return_up_forward_sharp.svg';
  static const String return_up_forward = 'return_up_forward.svg';
  static const String ribbon_outline = 'ribbon_outline.svg';
  static const String ribbon_sharp = 'ribbon_sharp.svg';
  static const String ribbon = 'ribbon.svg';
  static const String rocket_outline = 'rocket_outline.svg';
  static const String rocket_sharp = 'rocket_sharp.svg';
  static const String rocket = 'rocket.svg';
  static const String rose_outline = 'rose_outline.svg';
  static const String rose_sharp = 'rose_sharp.svg';
  static const String rose = 'rose.svg';
  static const String sad_outline = 'sad_outline.svg';
  static const String sad_sharp = 'sad_sharp.svg';
  static const String sad = 'sad.svg';
  static const String save_outline = 'save_outline.svg';
  static const String save_sharp = 'save_sharp.svg';
  static const String save = 'save.svg';
  static const String scale_outline = 'scale_outline.svg';
  static const String scale_sharp = 'scale_sharp.svg';
  static const String scale = 'scale.svg';
  static const String scan_circle_outline = 'scan_circle_outline.svg';
  static const String scan_circle_sharp = 'scan_circle_sharp.svg';
  static const String scan_circle = 'scan_circle.svg';
  static const String scan_outline = 'scan_outline.svg';
  static const String scan_sharp = 'scan_sharp.svg';
  static const String scan = 'scan.svg';
  static const String school_outline = 'school_outline.svg';
  static const String school_sharp = 'school_sharp.svg';
  static const String school = 'school.svg';
  static const String search_circle_outline = 'search_circle_outline.svg';
  static const String search_circle_sharp = 'search_circle_sharp.svg';
  static const String search_circle = 'search_circle.svg';
  static const String search_outline = 'search_outline.svg';
  static const String search_sharp = 'search_sharp.svg';
  static const String search = 'search.svg';
  static const String send_outline = 'send_outline.svg';
  static const String send_sharp = 'send_sharp.svg';
  static const String send = 'send.svg';
  static const String server_outline = 'server_outline.svg';
  static const String server_sharp = 'server_sharp.svg';
  static const String server = 'server.svg';
  static const String settings_outline = 'settings_outline.svg';
  static const String settings_sharp = 'settings_sharp.svg';
  static const String settings = 'settings.svg';
  static const String shapes_outline = 'shapes_outline.svg';
  static const String shapes_sharp = 'shapes_sharp.svg';
  static const String shapes = 'shapes.svg';
  static const String share_outline = 'share_outline.svg';
  static const String share_sharp = 'share_sharp.svg';
  static const String share_social_outline = 'share_social_outline.svg';
  static const String share_social_sharp = 'share_social_sharp.svg';
  static const String share_social = 'share_social.svg';
  static const String share = 'share.svg';
  static const String shield_checkmark_outline = 'shield_checkmark_outline.svg';
  static const String shield_checkmark_sharp = 'shield_checkmark_sharp.svg';
  static const String shield_checkmark = 'shield_checkmark.svg';
  static const String shield_half_outline = 'shield_half_outline.svg';
  static const String shield_half_sharp = 'shield_half_sharp.svg';
  static const String shield_half = 'shield_half.svg';
  static const String shield_outline = 'shield_outline.svg';
  static const String shield_sharp = 'shield_sharp.svg';
  static const String shield = 'shield.svg';
  static const String shirt_outline = 'shirt_outline.svg';
  static const String shirt_sharp = 'shirt_sharp.svg';
  static const String shirt = 'shirt.svg';
  static const String shuffle_outline = 'shuffle_outline.svg';
  static const String shuffle_sharp = 'shuffle_sharp.svg';
  static const String shuffle = 'shuffle.svg';
  static const String skull_outline = 'skull_outline.svg';
  static const String skull_sharp = 'skull_sharp.svg';
  static const String skull = 'skull.svg';
  static const String snow_outline = 'snow_outline.svg';
  static const String snow_sharp = 'snow_sharp.svg';
  static const String snow = 'snow.svg';
  static const String sparkles_outline = 'sparkles_outline.svg';
  static const String sparkles_sharp = 'sparkles_sharp.svg';
  static const String sparkles = 'sparkles.svg';
  static const String speedometer_outline = 'speedometer_outline.svg';
  static const String speedometer_sharp = 'speedometer_sharp.svg';
  static const String speedometer = 'speedometer.svg';
  static const String square_outline = 'square_outline.svg';
  static const String square_sharp = 'square_sharp.svg';
  static const String square = 'square.svg';
  static const String star_half_outline = 'star_half_outline.svg';
  static const String star_half_sharp = 'star_half_sharp.svg';
  static const String star_half = 'star_half.svg';
  static const String star_outline = 'star_outline.svg';
  static const String star_sharp = 'star_sharp.svg';
  static const String star = 'star.svg';
  static const String stats_chart_outline = 'stats_chart_outline.svg';
  static const String stats_chart_sharp = 'stats_chart_sharp.svg';
  static const String stats_chart = 'stats_chart.svg';
  static const String stop_circle_outline = 'stop_circle_outline.svg';
  static const String stop_circle_sharp = 'stop_circle_sharp.svg';
  static const String stop_circle = 'stop_circle.svg';
  static const String stop_outline = 'stop_outline.svg';
  static const String stop_sharp = 'stop_sharp.svg';
  static const String stop = 'stop.svg';
  static const String stopwatch_outline = 'stopwatch_outline.svg';
  static const String stopwatch_sharp = 'stopwatch_sharp.svg';
  static const String stopwatch = 'stopwatch.svg';
  static const String storefront_outline = 'storefront_outline.svg';
  static const String storefront_sharp = 'storefront_sharp.svg';
  static const String storefront = 'storefront.svg';
  static const String subway_outline = 'subway_outline.svg';
  static const String subway_sharp = 'subway_sharp.svg';
  static const String subway = 'subway.svg';
  static const String sunny_outline = 'sunny_outline.svg';
  static const String sunny_sharp = 'sunny_sharp.svg';
  static const String sunny = 'sunny.svg';
  static const String swap_horizontal_outline = 'swap_horizontal_outline.svg';
  static const String swap_horizontal_sharp = 'swap_horizontal_sharp.svg';
  static const String swap_horizontal = 'swap_horizontal.svg';
  static const String swap_vertical_outline = 'swap_vertical_outline.svg';
  static const String swap_vertical_sharp = 'swap_vertical_sharp.svg';
  static const String swap_vertical = 'swap_vertical.svg';
  static const String sync_circle_outline = 'sync_circle_outline.svg';
  static const String sync_circle_sharp = 'sync_circle_sharp.svg';
  static const String sync_circle = 'sync_circle.svg';
  static const String sync_outline = 'sync_outline.svg';
  static const String sync_sharp = 'sync_sharp.svg';
  static const String sync = 'sync.svg';
  static const String tablet_landscape_outline = 'tablet_landscape_outline.svg';
  static const String tablet_landscape_sharp = 'tablet_landscape_sharp.svg';
  static const String tablet_landscape = 'tablet_landscape.svg';
  static const String tablet_portrait_outline = 'tablet_portrait_outline.svg';
  static const String tablet_portrait_sharp = 'tablet_portrait_sharp.svg';
  static const String tablet_portrait = 'tablet_portrait.svg';
  static const String telescope_outline = 'telescope_outline.svg';
  static const String telescope_sharp = 'telescope_sharp.svg';
  static const String telescope = 'telescope.svg';
  static const String tennisball_outline = 'tennisball_outline.svg';
  static const String tennisball_sharp = 'tennisball_sharp.svg';
  static const String tennisball = 'tennisball.svg';
  static const String terminal_outline = 'terminal_outline.svg';
  static const String terminal_sharp = 'terminal_sharp.svg';
  static const String terminal = 'terminal.svg';
  static const String text_outline = 'text_outline.svg';
  static const String text_sharp = 'text_sharp.svg';
  static const String text = 'text.svg';
  static const String thermometer_outline = 'thermometer_outline.svg';
  static const String thermometer_sharp = 'thermometer_sharp.svg';
  static const String thermometer = 'thermometer.svg';
  static const String thumbs_down_outline = 'thumbs_down_outline.svg';
  static const String thumbs_down_sharp = 'thumbs_down_sharp.svg';
  static const String thumbs_down = 'thumbs_down.svg';
  static const String thumbs_up_outline = 'thumbs_up_outline.svg';
  static const String thumbs_up_sharp = 'thumbs_up_sharp.svg';
  static const String thumbs_up = 'thumbs_up.svg';
  static const String thunderstorm_outline = 'thunderstorm_outline.svg';
  static const String thunderstorm_sharp = 'thunderstorm_sharp.svg';
  static const String thunderstorm = 'thunderstorm.svg';
  static const String ticket_outline = 'ticket_outline.svg';
  static const String ticket_sharp = 'ticket_sharp.svg';
  static const String ticket = 'ticket.svg';
  static const String time_outline = 'time_outline.svg';
  static const String time_sharp = 'time_sharp.svg';
  static const String time = 'time.svg';
  static const String timer_outline = 'timer_outline.svg';
  static const String timer_sharp = 'timer_sharp.svg';
  static const String timer = 'timer.svg';
  static const String today_outline = 'today_outline.svg';
  static const String today_sharp = 'today_sharp.svg';
  static const String today = 'today.svg';
  static const String toggle_outline = 'toggle_outline.svg';
  static const String toggle_sharp = 'toggle_sharp.svg';
  static const String toggle = 'toggle.svg';
  static const String trail_sign_outline = 'trail_sign_outline.svg';
  static const String trail_sign_sharp = 'trail_sign_sharp.svg';
  static const String trail_sign = 'trail_sign.svg';
  static const String train_outline = 'train_outline.svg';
  static const String train_sharp = 'train_sharp.svg';
  static const String train = 'train.svg';
  static const String transgender_outline = 'transgender_outline.svg';
  static const String transgender_sharp = 'transgender_sharp.svg';
  static const String transgender = 'transgender.svg';
  static const String trash_bin_outline = 'trash_bin_outline.svg';
  static const String trash_bin_sharp = 'trash_bin_sharp.svg';
  static const String trash_bin = 'trash_bin.svg';
  static const String trash_outline = 'trash_outline.svg';
  static const String trash_sharp = 'trash_sharp.svg';
  static const String trash = 'trash.svg';
  static const String trending_down_outline = 'trending_down_outline.svg';
  static const String trending_down_sharp = 'trending_down_sharp.svg';
  static const String trending_down = 'trending_down.svg';
  static const String trending_up_outline = 'trending_up_outline.svg';
  static const String trending_up_sharp = 'trending_up_sharp.svg';
  static const String trending_up = 'trending_up.svg';
  static const String triangle_outline = 'triangle_outline.svg';
  static const String triangle_sharp = 'triangle_sharp.svg';
  static const String triangle = 'triangle.svg';
  static const String trophy_outline = 'trophy_outline.svg';
  static const String trophy_sharp = 'trophy_sharp.svg';
  static const String trophy = 'trophy.svg';
  static const String tv_outline = 'tv_outline.svg';
  static const String tv_sharp = 'tv_sharp.svg';
  static const String tv = 'tv.svg';
  static const String umbrella_outline = 'umbrella_outline.svg';
  static const String umbrella_sharp = 'umbrella_sharp.svg';
  static const String umbrella = 'umbrella.svg';
  static const String unlink_outline = 'unlink_outline.svg';
  static const String unlink_sharp = 'unlink_sharp.svg';
  static const String unlink = 'unlink.svg';
  static const String videocam_off_outline = 'videocam_off_outline.svg';
  static const String videocam_off_sharp = 'videocam_off_sharp.svg';
  static const String videocam_off = 'videocam_off.svg';
  static const String videocam_outline = 'videocam_outline.svg';
  static const String videocam_sharp = 'videocam_sharp.svg';
  static const String videocam = 'videocam.svg';
  static const String volume_high_outline = 'volume_high_outline.svg';
  static const String volume_high_sharp = 'volume_high_sharp.svg';
  static const String volume_high = 'volume_high.svg';
  static const String volume_low_outline = 'volume_low_outline.svg';
  static const String volume_low_sharp = 'volume_low_sharp.svg';
  static const String volume_low = 'volume_low.svg';
  static const String volume_medium_outline = 'volume_medium_outline.svg';
  static const String volume_medium_sharp = 'volume_medium_sharp.svg';
  static const String volume_medium = 'volume_medium.svg';
  static const String volume_mute_outline = 'volume_mute_outline.svg';
  static const String volume_mute_sharp = 'volume_mute_sharp.svg';
  static const String volume_mute = 'volume_mute.svg';
  static const String volume_off_outline = 'volume_off_outline.svg';
  static const String volume_off_sharp = 'volume_off_sharp.svg';
  static const String volume_off = 'volume_off.svg';
  static const String walk_outline = 'walk_outline.svg';
  static const String walk_sharp = 'walk_sharp.svg';
  static const String walk = 'walk.svg';
  static const String wallet_outline = 'wallet_outline.svg';
  static const String wallet_sharp = 'wallet_sharp.svg';
  static const String wallet = 'wallet.svg';
  static const String warning_outline = 'warning_outline.svg';
  static const String warning_sharp = 'warning_sharp.svg';
  static const String warning = 'warning.svg';
  static const String watch_outline = 'watch_outline.svg';
  static const String watch_sharp = 'watch_sharp.svg';
  static const String watch = 'watch.svg';
  static const String water_outline = 'water_outline.svg';
  static const String water_sharp = 'water_sharp.svg';
  static const String water = 'water.svg';
  static const String wifi_outline = 'wifi_outline.svg';
  static const String wifi_sharp = 'wifi_sharp.svg';
  static const String wifi = 'wifi.svg';
  static const String wine_outline = 'wine_outline.svg';
  static const String wine_sharp = 'wine_sharp.svg';
  static const String wine = 'wine.svg';
  static const String woman_outline = 'woman_outline.svg';
  static const String woman_sharp = 'woman_sharp.svg';
  static const String woman = 'woman.svg';
}
